function ro=acorimpresp(b,c,L)
%ACORIMPRESP Autocorrelation function computed for impulse response
%
%   Syntax
%   ro=acorimpresp(b,c,L)
%
%   Description
% ro=acorimpresp(b,c,L)calculates L+1 values of the autocorrelation 
%   function ro, according to the transfer function (b,c).
%   Only single poles are allowed for the system under investigation.
%
%   References: [DSV1, chap. 5.6.2, p. 410]
%
%   See also DSV-Lib: acor2tf
%            Matlab:  residue, residuez, polyval, impz

%% ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Hans W. Schuessler and Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(2,3,nargin, 'struct'))
if nargin < 3, L=100; end
[B,p,K]=residuez(b,c);            % residues of H(z)/z;
b_  = fliplr(b); c_ = fliplr(c);  % inverted poles and zeros
H_p = polyval(b_,p)./polyval(c_,p); 
Br  = B.*H_p;                    % residues of power function
K   = K*b_(end)/c_(end);
[bm,cm] = residuez(Br,p,K);      % coefficients of the model
     bm = real(bm); cm = real(cm);
ro      = impz(bm,cm,L)';         % autocorrelation function
%% [] - acorimpresp
