function  [b,c]=allpassgrpdelay(n,taug)
%ALLPASSGRPDELAY Design of a allpass for a prescribed group delay function
%   For a group delay function, defined at discrete points, the transfer 
%   function of an allpass of order n is approximated.   
%
%   Syntax
%   [b,c]=allpassgrpdelay(n,taug)
%
%   Description
% [b,c]=allpassgrpdelay(n,taug) calculate the transfer function (b,c) for a
%   sytem of order n, according to the prescribed groupdelay taug. Taug has 
%   to be defined for equidistant frequency points in the range [0,pi/2). 
%
%   References: [DSV1, chap. 5.6.1, p. 397]
%               [SchS90]
%
%   See also DSV-Lib: acor2tf, 
%            Matlab:  ifft, toeplitz, diag

%% ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors:  Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(2, 2, nargin, 'struct'))
%
taug=taug(:)';  
if length(taug)<n, 
   error('ALLPASSGRPDELAY: not enough values spezified for taug'); end
Taug=[taug taug(end-1:-1:2)];
D = ifft(Taug);     
H = toeplitz([0,D(2:n)],zeros(1,n)) + diag(1:1:n);
c = [1  -H\d];
b = fliplr(c);
%% [EOF] - allpassgrpdelay

