function y = fftfiltsav(b,x,Nfft)
%FFTFILTSAV Fast Convolution in overlap-save method
%
%   Syntax
%   y = fftfiltsav(b,x)
%   y = fftfiltsav(b,x,Nfft)
%
%   Description
% y = fftfiltsav(b,x) calculates the output sequence y for the input signal x
%   convolved by the filter kernel b, using Fast Convolution of length Nfft.
%   For the application of fast convolution the signal is separated into 
%   subsequences of length Nfft-nf+1, with nf the number of coefficients.
%   By default: Nfft=512.
% y = fftfiltsav(b,x,Nfft) enables in addition to define the length Nfft of
%   the FFT.
%
%   References: [DSV1, chap. 6.4.2, p. 452 ff]
%
%   See also DSV-Lib: 
%            Matlab:  fft, fftfilt, filter, conv, filtfilt, sosfilt

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(2,3, nargin, 'struct'))
if nargin<3, Nfft=512; end
%
B=fft(b(:),Nfft);       % Berechnung der bertragungsfunktion
ns=size(x,1);           % Vorbereitung der Blockabschnitte
nf=length(b);
ks= Nfft-nf+1; ns1=ks*ceil(ns/ks); 
xx=[zeros(nf-1,1);x(:);zeros(ns1-ns,1)]; % Anpassung des Eingangssig.
yy=zeros(ns1,1);
k0=1; k2=ks; kn=Nfft; 
while k0<ns,                          % Berechnung der Abschnitte
  x1 = xx(k0:kn);
  y1= ifft(fft(x1,Nfft) .* B, Nfft);  % Schnelle Faltung
  yy(k0:k2)=y1(nf:Nfft);
  k0=k0+ks;  kn=kn+ks; k2=k2+ks;
end
y=yy(1:ns);
%% [EOF] - fftfiltsav