function [y,zss,nov] = fixblockss(S,ss,p,v,zs,w,rmode,over)
%FIXBLOCKSS Fixed point filter realized in block computation
%
%   Syntax
%   y = fixblockss(S,ss,p,v)
%   y = fixblockss(S,ss,p,v,zs)
%   y = fixblockss(S,ss,p,v,zs,w)
%   y = fixblockss(S,ss,p,v,zs,w,round,over)
%   [y,zss,nov] = fixblockss(S,ss,p,v,...)
%
%   Description
%   ---------- in preparation ----------------
%
%   Example: DSV1, chap. 7.1.7.6
%                             
%   References: [DSV1, chap. 6.3]
%
%   See also DSV-Lib:  ss2block, fixquant

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(4,8, nargin, 'struct'))
if nargin<8, over='sat';    end
if nargin<7, rmode='round'; end
if nargin<6, w=16;          end
if nargin<5, zs=[];         end
%
ns=size(S,1); n=ns-p;  noc=0;
N=length(v); NN=N-p+1;
m=1; 
y=zeros(size(v));
if isempty(zs), 
      xp=zeros(ns,1);
else  xp=[zs;zeros(p,1)]; 
end
if isempty(ss), ss=[1 1]; end
%
v=v*ss(1);
while m <= NN
    xp(n+1:ns) = v(m:m+p-1);
    [xp,noci]=fixquant(S*xp,w,rmode,over);
    noc=noc+noci;
    y(m:m+p-1) = xp(n+1:ns);
    m=m+p;
end
y=y*ss(2);
if nargout>1, zss=xp(1:ns); end
if (nargout>2), 
nov = noc;
else
    if( max(noc)>0),
        warning('DSVLib:Overflow',' Overflow detected in FIXBLOCKSS');
    end
end
%% [EOF] - fixblockss