function [y,zss,nov] = fixcalfssos(CAP,v,zs,w,rmode,over)
%FIXCALFSSOS Quantized coupled allpass with 2. order blocks in lfs form
%   Realization of the substructures by cascades of 2. order lattice blocks
%   in lfs form.
%
%   SYNTAX
%   y  = fixcalfssos(CAP,v)
%   y  = fixcalfssos(CAP,v,zs)
%   y  = fixcalfssos(CAP,v,zs,w)
%   y  = fixcalfssos(CAP,v,zs,w,rmode)
%   y  = fixcalfssos(CAP,v,zs,w,rmode,over)
%   [y,zss,nov]=fixcalfssos(CAP,v,...)
%
%   Description
%   ---------- in preparation ----------------
%                             
%   References: [DSV1, chap. 6.6.3]
%
%   See also DSV-Lib:  fixlfssos, fixquant

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(2,6, nargin, 'struct'))
if nargin<6, over='sat';      end
if nargin<5, rmode='nearest'; end
if nargin<4, w=16;            end
if nargin<3, zs=[];           end
%
y=zeros(size(v));  noc=0;
fac=CAP.coef{3};
for i=1:2
    lfs=CAP.coef{i}{:};
    l=size(lfs,1);
    if isempty(zs), zsi=zeros(l,2); 
    else       zsi=zs(:,2*i-1:2*i);
    end
    [yi,zsi,noci]=fixlfssos(lfs,v,zsi,w,rmode,over);
    noc=noc+noci;
    y = y + yi;
    zso(1:l,2*i-1:2*i)=zsi;
end
[y,noci]=fixquant(y*fac,w,rmode,over);
noc = noc + noci;

%%
if (nargout>1), zss = zso; end
if (nargout>2), 
nov = noc;
else
    if( max(noc)>0),
        warning('DSVLib:Overflow',' Overflow detected in FIXCALFSSOS');
    end
end
