function [y,zss,nov]=fixlfssos(lfs,v,zs,w,rmode,over)
%FIXLFSSOS Quantized digital allpass with blocks in lfs form
%   Realization of second order sections by lattice filter blocks,
%   in the lfs form
%
%   SYNTAX
%   y  = fixlfssos(lfs,v)
%   y  = fixlfssos(lfs,v,zs)
%   y  = fixlfssos(lfs,v,zs,w)
%   y  = fixlfssos(lfs,v,zs,w,rmode)
%   y  = fixlfssos(lfs,v,zs,w,rmode,over)
%   [y,zss,nov]=fixlfssos(lfs,v,...)
%
%   Description
%   ---------- in preparation ----------------
%                             
%   References: [DSV1, chap. 6.5.3.5]
%
%   See also DSV-Lib: fixcalfssos, fixquant

%% ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(3,6, nargin, 'struct'))
if (nargin<6), over ='sat';    end
if (nargin<5), rmode='nearest';end
if (nargin<4), w  = 16; end
if (nargin<3), zs = []; end
nb=size(lfs,1);
if(isempty(zs)), zs = zeros(nb,2); end
noc = zeros(nb,1);
xx=v;
for ib = 1:nb
  al = lfs(ib,1); be  = lfs(ib,2);
  [xx,zs(ib,:),noc(ib)] = fixlfs(al,be,xx,zs(ib,:),w,rmode,over);
end
% set output parameter
y  = xx;
if (nargout>1), zss = zs; end
if (nargout>2), 
nov = noc;
else
    if( max(noc)>0),
        warning('DSVLib:Overflow',' Overflow detected');
    end
end
%
%% -------Hilfsfunktion---------------------------------
function [y,zi,noc]=fixlfs(al,be,v,zi,w,rmode,over)
% 
LEN = length(v); y=zeros(size(v)); 
n=0; noc=0;
if al~=0,
  while n < LEN,
    n = n + 1;
    x=v(n);
      [x1,inoc] = fixquant(x * al + zi(1) * al,w,rmode,over);
      noc = noc + inoc;
      x2 = -x1 + x;
      y(n) = x1 + zi(1);
      if be>=0,
        [x1,inoc] = fixquant(x2 * be + zi(2) * be,w,rmode,over);
        x2 = - x1 + x2;
      else 
        [x1,inoc] = fixquant(x2 * be - zi(2) * be,w,rmode,over);
        x2 =  x1 + x2;
      end
      noc = noc + inoc;
      zi(1)=x1 + zi(2);
      zi(2)=x2;
  end
else
  while n < LEN,
    n = n + 1;
    x=v(n);  
    if be>=0,
      [x1,inoc] = fixquant(x * be + zi(1) * be,w,rmode,over);
      x2 = - x1 + x;
    else 
      [x1,inoc] = fixquant(x * be - zi(1) * be,w,rmode,over);
      x2 =  x1 + x;
    end
    noc = noc + inoc;
    y(n)=x1 + zi(1);
    zi(1)=x2;
  end
end
%% [EOF] - dbllfssos
