function [y,zss,nov] = fixwf2sos(wdf,s,v,zs,w,rmode,over)
%FIXWF2SOS Quantized digital cascade filter with blocks in wf2 form
%   Realization of second order sections by wave digital filter blocks,
%   in the wf2 form, according to Meerkoetter and Wegener [MeeW76]
%
%   SYNTAX
%   y  = fixwf2sos(wdf,s,v)
%   y  = fixwf2sos(wdf,s,v,zs)
%   y  = fixwf2sos(wdf,s,v,zs,w)
%   y  = fixwf2sos(wdf,s,v,zs,w,rmode)
%   y  = fixwf2sos(wdf,s,v,zs,w,rmode,over)
%   [y,zss,nov]=fixwf2sos(wdf,s,v,...)
%
%   Description
%   ---------- in preparation ----------------
%                             
%   References: [DSV1, chap. 6.5.3.5]
%
%   See also DSV-Lib:  fixwf1sos, fixdf1sos, fixquant

%% ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(3,7, nargin, 'struct'))
%
if (nargin<7), over = 'sat';  end
if (nargin<6), rmode='magn';end
if (nargin<5), w    = 16; end
if (nargin<4), zs = [];   end
nb = size(wdf,1); ns=length(s);
if ns < 2, s=[s,ones(1,1)]; ns=2; end
if (ns < nb+1), s = [s(1),ones(1,nb+1-ns),s(2)]; end
% reset state variables and overflow counter
if(isempty(zs)), zs = zeros(nb,2); end
noc = zeros(nb,2);
xx = v;
%%
xx = xx*s(1);
for ib = 1:nb
  xx = xx * s(ib);   % no quantization after scaling mult.
  b  = wdf(ib,1:3); a  = wdf(ib,4:6);
  [xx,zs(ib,:),noc(ib,1)] = fixwf2(b,a,xx,zs(ib,:),w,rmode,over);
  % check for one or shift multipliers
    if(ib ~=nb && s(ib+1)~=1),
       if(ispower2(s(ib+1))),  % overflow check only
          [xx,noc(ib+1,2)] = fxquant( xx, w, 'none', over);
       else
          [xx,noc(ib+1,2)] = fxquant( xx, w, 'nearest', over);
       end
    end
    if ib==nb,
       [xx,noc(nb,2)] = fixquant( xx, w,'nearest', over);
    end
end
% set output parameter
y  = xx * s(nb+1);
if (nargout>1), zss = zs; end
if (nargout>2), nov = noc;
else
    if( max(noc(:))>0),
        warning('DSVLib:Overflow',' detected in FIXWF2SOS');
    end
end
%
%% -------Hilfsfunktion---------------------------------
function [y,zi,noc]=fixwf2(b,ga,v,zi,w,rmode,over)
% 
x = zi';   %x1,x2,0
b(2:3)=-b(2:3);
ga = ga(2:3);
y=zeros(size(v)); LEN = length(v); noc=0;
n = 0;
while n < LEN,
     n = n + 1;
     [u,inoc] = fixquant(v(n) + ga * x,w,'nearest',over);
     noc = noc + inoc;
     y(n)= b * [u;x];
     u1 = u - x(2);
     [x(2),inoc] = fixquant(u + x(1),w,rmode,over);
     noc = noc + inoc;
     [x(1),inoc] = fixquant(u1,w,rmode,over) ;
     noc = noc + inoc;
end
zi = x';
%% [] - dblwf1sos
