function [y,zss] = flddf1(num,den,v,zs,wm,rmode)
%FLDDF1 Float point filter realisation in df1 form
%   Realisation
%   - summation of the products in double precission
%   - one quantizer after the summation point defined by rmode
%   - wordlength of mantissa wm (without sign)
%  
%   Default values:
%     wm = 16:   round='nearest'; 
%
% Floatpoint number overflow is currently not controlled!
%
%   Syntax
%   y = flddf1(num,den,v)
%   y = flddf1(num,den,v,zs)
%   y = flddf1(num,den,v,zs,wm)
%   y = flddf1(num,den,v,zs,wm,rmode)
%   [y ,zss]= flddf1(num,den,v,...)
%
%   Description
%   ---------- in preparation ----------------
%                             
%   References: 
%
%   See also DSV-Lib:  flddf1sos, fldquant, fixquant

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(3,6, nargin, 'struct'))
%
if (nargin<6), rmode='nearest';end
if (nargin<5), wm  = 16; end
if (nargin<4), zs = []; end
ndeg=length(den)-1;  nd1=ndeg-1;
% reset state variables
if(isempty(zs)), zsnum = zeros(ndeg,1); zsden=zsnum;
else
   if length(zs)~=ndeg, error('FLDDF1: inconsitent state variables'); end
    zsnum=zs(:,1); zsden=zs(:,2);
end
len=length(v); 
b= num; 
if den(1)== 1, a=den(2:end);
else   error('FLDDF1: denominator not normalized');
end
%%
n=0; 
while n<len,
    n=n+1;
    zsnum = [v(n);zsnum];
    u = b * zsnum - a * zsden;
    u = fldquant(u,wm,rmode);
    %
    y(n)=u;
    zsnum = zsnum(1:ndeg);
    zsden = [u;zsden(1:nd1)];
end
if nargout>1,
    zss = [zsnum zsden];
end
%% [EOF] -flddf1
