function [y,zss] = flddf1sos(sos,s,v,zs,wm,rmode,over)
%FLDDF1SOS Float point filter cascade realisation in df1sos form
%   Realisation
%   - summation of the products in double precission
%   - one quantizer after the summation point of the 2. order sections
%   - additional quantizer after block scaling for scaling factors ~=0
%   - quantization defined by rmode
%   - wordlength of mantissa wm (without sign)
%  
%   Default values:
%     wm = 16:   round='nearest'; 
%
% Floatpoint number overflow is currently not controlled!
%
%   Syntax
%   y = flddf1sos(sos,s,v)
%   y = flddf1sos(sos,s,v,zs)
%   y = flddf1sos(sos,s,v,zs,wm)
%   y = flddf1sos(sos,s,v,zs,wm,rmode)
%   [y ,zss]= flddf1sos(sos,s,v,...)
%
%   Description
%   ---------- in preparation ----------------
%                             
%   References: 
%
%   See also DSV-Lib:  flddf1, fldquant

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(3,7, nargin, 'struct'))
if (nargin<7), over ='none';    end
if (nargin<6), rmode='round';end
if (nargin<5), wm  = 16; end
if (nargin<4), zs = []; end
nsec = size(sos,1);  ns   = length(s);
if ns < 2, s=[s,ones(1,1)]; ns=2; end
if ns < nsec+1,s = [s(1),ones(1,nsec+1-ns),s(2)]; end 
% reset state variables
if(isempty(zs)), zs = zeros(nsec,4); end
noc = zeros(nsec,2);
xx = v;
for isec = 1:nsec
    if s(isec)~=1.,
      [xx,noc(isec,2)] = fldquant( xx*s(isec),wm,'round', over);
    end
    co  = [sos(isec,1:3),-sos(isec,5:6)];
    if(sos(isec,4)~=1), 
        error('FLDDF1SOS: denominator coefficients?');
    end
    [xx,zs(isec,:),noc(isec,1)] = fd1fi(co,xx,zs(isec,:),wm,rmode,over);
end
xx = xx * s(nsec+1);
% set output parameter
y  = xx;
if (nargout>1), zss = zs; end
if (nargout>2), 
nov = noc;
else
    if( max(noc(:))>0),
        warning('DSVLib:FldOverflow',' Overflow detected');
    end
end

% ----------------------------------------------------------
function [y,zi,noc] = fd1fi(co,v,zi,wm,rmode,over)
%   zi = state variable x11 x21 || x21 x22
x = zi.';
noc = 0;
LEN = length(v);
n = 0;  y=zeros(size(v));
while n < LEN,
     n = n + 1;
     x=[v(n);x(1:4)];
     [u,inoc] = fldquant((co * x),wm,rmode,over);
     y(n) = u;
     x(3) = u;
     noc = noc + inoc;
end
zi = (x(1:4)).';
%% [EOF] -flddf1sos
