function [yp,ya,zss] = fldiirlat(r,v,zs,wm,rmode)
%FLDIIRLAT IIR Float point filter in lattice strucure
%   Realisation
%   - summation of the products in double precission
%   - quantizer after the summation points 
%   - quantization defined by rmode
%   - wordlength of mantissa wm (without sign)
%
%   Default values:
%     wm = 16:   rmode='nearest'; 
%
% Floatpoint number overflow is currently not controlled!
%
%   yp  allpole filter
%   ya  allpass filter
%
%   Syntax
%   [yp,ya] = fldiirlat(r,v)
%   [yp,ya] = fldiirlat(r,v,zs)
%   [yp,ya] = fldiirlat(r,v,zs,wm,rmode)
%   [yp,ya,zss] = fldiirlat(r,v,...)
%
%   Example:
%      phi=[0.6 0.3 -0.3 -0.6]';
%      r0 = 0.99;
%      z=r0*exp(j*phi*pi); 
%      [b,c]= zp2tf(1,z,1);
%         r = p2latc(c)
%   [yp,ya] = fldiirlat(r,v,[],wm,'round'); 
%
%   See also: p2latc, fldfirlat
%   SPTool: tf2latc, latcfilt

%% ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(3,5, nargin, 'struct'))
%
if nargin < 5, rmode='neaest'; end
if nargin < 4, wm=16;         end
if nargin < 3, zs=[];         end
%%
lr=length(r); lv = length(v);      
if isempty(zs), z=zeros(1,lr+1); else z=[zs 0]; end
      yp=zeros(size(v));  ya=yp;
      for k=1:lv                          
        a=v(k);                             
        for l=lr:-1:1                      
          a  = fldquant(a-r(l)*z(l),wm,rmode);                      
          z(l+1)=fldquant(r(l)*a+z(l),wm,rmode);                 
        end                                  
        z(1)=a;                             
        yp(k)=a;        % all-pole      
        ya(k)=z(lr+1);  % allpass                                        
      end                    
if nargout>2, zss=z(1:lr); end
%% [EOF] - fldiirlat
