function [y,noc] = fldquant(x,wm,rmode,over)
%FLDQUANT: Quantization float-point arithmetic
%   Realization 
%   Quantization of mantissa to wm digits (excluding sign)
%   Quantization modes for state variables
%       RMODE:  'convergent'    convergent rounding (mathematical
%                               rounding)
%               'nearest'       rounding to nearest level (two's comp)
%               'round','zero'  sign magnitude rounding   
%               'trunc','floor' 2's complement truncation
%               'magn' ,'fix'    magnitude truncation
%               'none'          no quantization
%
%   Default values:
%     wm = 16:   round='nearest'; 
%
% Floatpoint number overflow is currently not controlled!
%
%   Syntax
%   y = fldquant(x,w)
%   y = fldquant(x,w,rmode)
%   [y,noc] = fldquant(x,w,...)  % for compatibility to fixquant, only 
%
%   Description
%   ---------- in preparation ----------------
%                             
%   References: 
%
%   See also DSV-Lib: flddf1sos, flddf2sos
%            Matlab:  convergent, nearest, round, floor, fix
%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(2,4, nargin, 'struct'))
%% Quantization
if nargin < 4, over='none';   end
if ~isequal(over,'none'), 
    warning('DSVLib:Float','overflow check not implemented'); 
    over ='none';
end
if ~isinf(wm),
   if nargin < 3, rmode='round'; end
   [f,e]= log2(x);
   f_   = fixquant(f,wm+1,rmode,over);
   y   = pow2(f_,e);
else
   y=x;
end
if nargout >1, noc=0; end
%% [EOF] -fldquant
