 function soszplane(sos)
%SOSZPLANE: Plot SOS zeros and poles with block numbers
%
%   Syntax
%   soszplane(sos)
%
%   sos SOS coefficient Array
%
%   Description
%   The pole and zero are calculated from the SOS coefficients and 
%   plotted in the x,y-plane, simular to the Matlab function zplane(.)
%   In addition the poles and zeros are marked by the  numbers of the 
%   2. order blocks within the cascade
%                             
%   References: 
%
%   See also Matlab:  zplane

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.01   Release 2010_2
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(1,1, nargin, 'struct'))
%
nb=size(sos,1);
[zz,zp]=sos2zp(sos);
zz=zz(abs(zz)~=0);  zp=zp(abs(zp)~=0);
zplane(zz,zp)
% Labelling of zeros and poles
zps=zp(imag(zp)>=0);
for n=1:nb,
    zz = roots(sos(n,1:3));
    if ~isempty(zz),
      zz=zz((imag(zz)>=0 & abs(zz)>0));
      x= real(zz(1))*1.1; y=imag(zz(1))*1.1;
      text(x,y,int2str(n))
    end
    zp = roots(sos(n,4:6));
    zp=zp((imag(zp)>=0 & abs(zp)>0));
    if ~isempty(zp)
      [dzp,i]=sort(zp-zps); dzp=dzp(2);
    else
      dzp = 0;
    end
    dir=0.1*complex(imag(dzp),-real(dzp))/abs(dzp);
    zp1 = zp+dir;
    if abs(zp1)>abs(zp), dir=-dir; zp1=zp+dir; end
    x= real(zp1); y=imag(zp1);
    text(x,y,int2str(n))
end
%% [EOF] - soszplane
