function K = gram(A,b)
%GRAM  "Gramsche-Matrix" for discrete systems
%
%   Syntax
%   K = gram(A,B)
%   W = gram(A',C')
%   
%   Description
% K = gram(A,b)calculates the K-Matrix (Controllmatrix) for a
%   discrete system, defined by the state matrices (A,B,C,D).
% 
% W = gram(A',C') calculates the W-Matrix (observation matrix) for a
%   discrete system, described in the state variable form.
%
%   References: [DSV1, chap. 5.3.1]
%
%   See also Matlab:  kron, reshape

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Hans.W. Schuessler
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
Q = b*b'; q = Q(:);
n = size(Q,1);
E = eye(n^2);
R = E - kron(A,A); k = R\q;
K = reshape(k,n,n);
%% EOF - gram
