function [Pxx,W] = covlds(v,L,M)
%COVLDS Power spectrum density (PSD) via covariance sequence
%   German: Leistungsdichtespectrum (LDS)
%
%   Syntax
%   [Pxx,W] = covlds(v,L,M)
%
%   Description
% [Pxx,W] = covlds(v,L,M) calculates M values of the PSd for the 
%   sequence v, using the parameter L for the Hann-Window
%   
%   References: [DSV1, chap. 3.3.5.4]
%
%   See also DSV-Lib: wblds, rader

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Hans W. Schuessler and Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(3,3, nargin, 'struct'))
%
l = [0:L]; 
fh= 0.5*(1+cos(l*pi/L))';  % modifiziertes Hann-Fenster
psi = rader(v,L);          % Bestimmung der Kovarianzfolge
psi=psi(L+1:end);
Psi = 2*real(fft(fh.*psi,M))-psi(1);
Pxx = Psi(1:M/2);
if nargout>1,W = (0:M/2-1)*2*pi/M; end
%% [EOF] - covlds
