function scal = dsv_filternorm (b,a,pnorm)
% DSV_FILTERNORM -- Compute different norms for scaling
% SCAL = DSP_FILTERNORM (b,a,pmorm)
% The scalingfactor SCAL is calculated for the transferfunction 
% of a IIR filter defined by the numerater polynom b
% and the denominator polynom a for different norms specified by 
% the string pnorm
% pmorm = 'none'    no scaling / return scal = 1
%       = inf       L-inf norm
%       = 'L-inf'   L-inf norm
%       = 2         L-2 norm
%       = 'L-2'     L-2 norm
%       = 1         l-1 norm   absolut values of impulse response
%       = 'l-imp'   l-1 norm
%       = 'abs'     l-1 norm

%% ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.01  Release 2010_2
%   Copyright 2007 by authors - not released for commercial use
%%
error(nargchk(2,3, nargin, 'struct'))
%
if nargin<3, pnorm='inf'; end
switch pnorm
case 'none'
    scal = 1;
    return
    
case {inf 'L-inf' 'Linf' 'inf'}
   fabs = abs(freqz(b,a,1024));
   scal = max(fabs);
   if scal == inf,
       warning ('DSVlib:dsv_filternorm', 'Inf values removed by zero')
       ind = isinf(fabs);
       indl = find(ind);
       disp(fabs(min(indl)-2:max(indl)+2))
       fabs(ind) =0;
       scal=max(fabs);
   end
   return
%    
case {2 'L-2' 'L-two' 'two'}
    scal = sqrt(dsp_energy (b,a));      
case { 1 'l-imp' 'abs'}
    maxradius = max(abs(roots(a)));
    if(maxradius >= 1),
        error ('DSV_FILTERNORM: l-imp -- numerical problems'); 
    end
    neff = impzlength(b,a,1e-8);
    H=impz(b,a,ceil(neff));
    scal = norm(H,1);
    
otherwise
    error ('DSV_FILTERNORM: no legal norm for scaling')
end
%% [EOF] - dsv_filternorm
        
