function [soc_sort,ss] = sos_sort (soc,s,dir_flag)
% DSP_CAS_SORT  Sort the poles and zeros of a SOS
% 
% Conjungate complex poles of the cascade are sorted 
% in descendenting order, beginning with the pole closest 
% to the unit circle (DIR_FLAG='down'). Real poles are sorted 
% behind the complex ones. Zeros are orderd according to their 
% distance to the poles,beginning with the zero closest to the 
% most critical pole. For DIR_FLAG='up'the poles are ordered in
% ascending order (default)
%
%% ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Hans W. Schuessler and Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%

nb = size(soc,1);
fact = 1;
if(nargin > 1),
    if isnumeric(s), fact=s; end
end
zp =[];
zz =[];
for i = 1:nb
    % get poles and zeros
    a    = soc(i,4:6);      
    fact = fact/a(1);       %remove denominator scaling
    a    = a /a(1);
    b    = soc(i,1:3);
    fact = fact * b(1); % remoce numerator scaling
    b    = b/b(1);
    
    zp = [zp;roots(a)];
    zz = [zz;roots(b)];
end

dir = 'up';
if(nargin > 2),
    if(isstr(dir_flag)), dir = dir_flag; end
end
% sort zeros und poles to SOS
[soc_sort,ss] = zp2sos(zz,zp,fact,dir);

