function [wdf_,g_]=scaling_wf1sos(wdf,g,norm,over)
%SCALING_WD1SOS Scaling of the  cascade 2. order sections in wf1sos-Form 
%
%
%   Syntax
%   [wdf_,g_]=scaling_wf1sos(wdf,g)
%   [wdf_,g_]=scaling_wf1sos(wdf,g,norm)
%   [wdf_,g_]=scaling_wf1sos(wdf,g,norm,over)
%
%   Description
% [wdf_,g_] = scaling_wf1sos(wdf,g,'abs') The filter defined by the 
%   SOS block and the scaling parameters s is scaled for the wf1sos-form 
%   according to the absolute norm (norm = 'abs'). 
%   Scaling points are currently tested in front of the state variables, 
%   according to overflow modes 'wrap' and 'sat'('saturate').
%
%   References: [DSV1, chap. 6.6.3.5]
%
%   See also DSV-Lib: sos2wdf, dsv_filternorm
%            Matlab:  conv

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors:  Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(2,4, nargin, 'struct'))
if nargin<4, over='sat';  end
if nargin<3, norm ='inf'; end
%
nb = size(wdf,1);
scalm = 1.;
g_=ones(nb+1,1);  wdf_=wdf;
%
bb = 1.; aa = 1.; sp=1.;
for i = 1:nb
  bet0=wdf(i,1); bet1=wdf(i,2); bet2=wdf(i,3);
  ga1=wdf(i,5); ga2=wdf(i,6);
  a=[1,-(ga1+ga2), 1+ga1-ga2];
  aa = conv (aa,a);
  bb1 = conv (bb,[bet0,-(bet1+bet2), 1+bet1-bet2]);
  fact = 1/dsv_filternorm(bb1,aa,norm);
  switch over
    case {'sat','saturate'}
    bb2=conv (bb,[(bet0*ga1-bet1),ga2*(bet0+bet1)-bet2*(1+ga1),0]);
    fact2 = 1/dsv_filternorm(bb2,aa,norm);
    bb3=conv (bb,[ga2*bet0-bet2,bet1*(1-ga2)-ga1*(bet0-bet2),0]);
    fact3 = 1/dsv_filternorm(bb3,aa,norm);
    fact=min([fact,fact2,fact3]);
    case 'wrap'
    otherwise,error('error: Scaling_WF1SOS -- parameter not def.');
  end
  bb=bb1;
  if (fact > scalm), fact = scalm; end
  sp =sp * fact;  bb = bb * fact;
  wdf_(i,1:3) = wdf(i,1:3) * fact;
end
% set final scaling factor
g_(nb+1) = prod(g) / sp;
%% [EOF] - scaling_wf1sos
