function [sos1,s1]=sosorder(sos,s,type)
%SOSORDER  Sorting SOS Block in up-order and in special allocation 
%
%   Syntax
%   [sos1,s1]=sosorder(sos,s)
%   [sos1,s1]=sosorder(sos,s,type)
% 
%   type = 'up', 'down', 'up-sh' or 'Down-sh')
%
%   Description
%   ------- in preparation ---------
%
%   References: [DSV1, chap. 7.1.7.5], [Deh03]
%
%   See also DSV-Lib: sos_sort

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(2,3, nargin, 'struct'))
nb=size(sos,1);
[soss,s1]=sos_sort(sos,s);
%
if nargin<3, type='up'; end
%
switch type
    case 'up'
     ISECN = 1:nb;    ISECD = 1:nb;
    case 'down'
     ISECN = nb:-1:1; ISECD = nb:-1:1;    
    case 'up-sh'
     ISECN=[2:nb,1];  ISECD = 1:nb;
    case 'down-sh'
     ISECN= nb:-1:1;  ISECD = [1,nb:-1:2];
    otherwise
        error ('SOSORDER: Allocation type not def.')
end
sos1(:,1:3)=soss(ISECN,1:3);
sos1(:,4:6)=soss(ISECD,4:6);
%% [EOF] - sosorder
      
