function [sosr,sr]=sosround (sos,s,wq)
%SOSROUND Rounding of the coefficients and the scaling factors 
%   of a SOS structure 
%
% [sosr,sr]=sosround(sos,s,wq) Rounds the coefficients of the SOS structure 
%   to wq digits behind the fixed point. The stability of the system is
%   proved and, if necessary, corrected.
%   
% See also Matlab: round 

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(3,3, nargin, 'struct'))
nb= size(sos,1); Q=2^(-wq);
%
sosr=zeros(nb,6);
for i=1:nb,  
 sosr(i,:) = Q * round(sos(i,:) /Q);
 % Check stable
 if sosr(i,6) >=1.0,
     disp(['notstable a2 ',num2str(sosr(i,6))])
     sosr(i,6) = sosr(i,6)-Q;
     disp(sosr(i,6))
 end
 if abs(sosr(i,5))>= sosr(i,6)+1,
     disp(['notstable a1 ',num2str(sosr(i,5))])
     sosr(i,5)=sign(sosr(i,5))*(abs(sosr(i,5))-Q);
     disp(sosr(i,5))
 end
end
sr   = Q * round(s /Q);
%% EOF] - sosround
