function C=binchr(chi,N,p)
%BINCHR Characteristic  function of a binominal distrib. discrete sequence
%
%   Syntax
%   C=binchr(chi,N)         
%   C=binchr(chi,N,p)
%
%   Description
% C=binchr(chi,N) The characteristic function for the binominal discrete 
%   distribution in N points is calculated for the values chi and the  
%   parameter p (distribution of 0 and 1) The parameter p = 0.5  is chosen 
%   by default.
% C=binchr(chi,N,p) allows to define the probability parameter in the range
%   p =[0,1).
% 
%   References: [DSV1, Chap. 3.1.3 p.145 ff]
%
%   See also DSV-Lib: randbin, binvdf, normchr, rectchr, chi2chr, raychr, 
%                     stuchr, expchr

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(2,3, nargin, 'struct'))
if nargin<3, p=0.5; end
%
C = (p*exp(j*chi)+ (1-p)).^N;
%% [EOF] - binchr

