function pv=binvdf(N,p)
%BINVDF Probability density function of the discrete binominal distribution
%        German: Verteilungsdichtefunktion (vdf).
%
%   Syntax
%   pv=binvdf(N,p)
%
%   Description
%   A random sequence of discrete values (e.g. zero and one) has a
%   binominal distribution of order N, if it takes the values 0,1,...,N with
%   the discrete density function
%                   N               k      (N-k)
%           pv(V) = SUM (N over k) p^ (1-p)^      delta(V-k).
%                  k=0
%   p is the probability for getting a "one" value.
%
%   pv=binvdf(V) calculates the discrete probability density function pv(N,p) 
%   of the binominal distribution with probability p. The density 
%   function is computed for the  values V = 0,1,...,N.
%

%   References: [DSV1, Chap. 3.1.1, p. 137],[Pap91]
%
%   See also DSV_Lib: randbin, binchr
%             MATLAB: nchoosek

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(2,2, nargin, 'struct'))
%
pv=zeros(1,N+1);
for k=0:N
pv(k+1)=nchoosek(N,k)*p^k*(1-p)^(N-k);
end
%% [EOF] - binvdf
