function C=chi2chr(chi,nf)
%CHI2CHR Characteristic function of a Chi^2-distributed sequence
%
%   Syntax
%   C=chi2chr(chi,nf)
%
%   Description
%   C=chi2chr(chi,nf) outputs the characteristic function of the
%   Chi^2-distribution with degree of freedom nf for the abscissa values,
%   given in the vector chi.
%
%   References: [DSV1, Chap. 3.1.3, p.148]
%
%   See also DSV-Lib: randchi2, chi2vdf, rectchr, normchr, stuchr, raychr, 
%                     expchr, sinchr, binchr.

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(2,2, nargin, 'struct'))
%
if nf<1 || ~rem(nf,1)==0,         % check for integer
    error('CHI2CHR: parameter n integer > 0?'); end
C = (1+4*chi.*chi).^-(nf/4).*exp(j*nf/2*atan(2*chi));
%% [EOF] - chi2chr

