function pv=chi2vdf(V,nf)
%CHI2VDF Probability density function  of the chi^2 distribution
%        German: Verteilungsdichtefunktion (vdf)
%
%   Syntax
%   pv=chi2vdf(V,nf)
%
%   Description
%   pv=chi2vdf(V,n) calculates the probability desnsity function pv 
%   of the chi^2 distribution with a degree of freedom nf for all random 
%   values defined in the vector V
%
%   References: [DSV1, chap. 3.1.1, p. 136]
%
% See also DSV_Lib: randchi2, normvdf, rectvdf, stuvdf, rayvdf, expvdf, 
%                   sinvdf, binvdf

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(2,2, nargin, 'struct'))
%
if nf<1 || ~rem(nf,1)==0,  
    error('CHI2VDF: parameter n integer > 0?'); end
nh=nf/2;
fac=1./(2^nh*gamma(nh));
pv=zeros(size(V));
ind=find(V>=0);
pv(ind)=fac*V(ind).^(nh-1).*exp(-V(ind)/2);
%% [EOF] - chi2vdf