function y=covariance(v,L)
%COVARIANCE Calculation of the Covariance Sequence using FFT
%   The covariance sequence of length L is calculated by cyclic 
%   convolutions using a FFT of length N. Taking N as the next larger 
%   power of two compared to length of sequence v(k) plus L
%
%   Syntax
%   y=covariance(v,L)
%
%   Description
% y=covariance(v,L) calculates L+1 values of the covariance sequence 
%   of input sequenvce v(k).
%
%   References: [DSV1, Chap. 3.1.4 p.186 ff]
%   See also DSV-Lib: xcov
%            Matlab:  xcov

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(2,2, nargin, 'struct'))
%
   N= 2^nextpow2(length(v)+L);
   v1=v(:);
   V=fft(v1,N);
   Va=real(V).^2+imag(V).^2;
   y1=ifft(Va,N);
   y1=y1(1:L+1)./(N-[0:1:L]');
   y=[flipud(y1(2:L+1));y1];
%% [EOF] - covariance
