function pv=expvdf(V,alpha)
%EXPVDF Probability density function  of the exponential distribution
%        German: Verteilungsdichtefunktion (vdf)
%
%   Syntax
%   pv=expvdf(V,alpha)
%
%   Description
%   pv=expvdf(V) calculates the probability desnsity function pv 
%   of the exponential distributed random signal with parameter alpha=1. 
%   The density function is computed for the abscissa values given in 
%   vector V.
%
%   pv=expvdf(V,alpha) calculates the density distribution for a variable
%   parameter alpha.
%
%   References: [DSV1, Chap. 3.1.2, p. 143],[Pap91]
%
%   See also DSV_Lib: randexp, normvdf, rectvdf, chi2vdf, stuvdf, rayvdf, 
%                     sinvdf, binvdf

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(2,2, nargin, 'struct'))
%
if nargin<2, alpha=1; end
V=V(:);
pv= zeros(size(V));
ind=find(V>=0);
pv(ind)=alpha*exp(-alpha*V(ind));
%% [EOF] - expvdf
