function C=normchr(chi,sig,mu)
%NORMCHR Characteristic Function of a normal dist. sequence
%   The characteristic function of a normal distributed random 
%   signal is calculated for the Values, defined in the vector chi. 
%   The distribution density pv is defined by the parameters sig
%   and mu of the normal distribution.
%
%   Syntax
%   C=normchr(chi)
%   C=normchr(chi,sig)
%   C=normchr(chi,sig,mu)
%
%   Description
% C=normchr(chi) calculates the char. function  of a symmetric 
%   distribution (mu=0) and the default value sig=1.
% C=normchr(chi,sig,mu) calulates the char. function for a normal
%   distribution with the optional values sig and mu.
%
%   References: [DSV1, Chap. 3.1.3 p.145 ff]
%
%   See also DSV-Lib: normvdf, rectchr, chi2chr, stuchr, raychr, 
%                     expchr, sinchr, binchr
%            Matlab:  randn

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(1,3, nargin, 'struct'))
%
if nargin<3, mu =0; end
if nargin<2, sig=1; end
C=exp(j*mu*chi).*exp(-(chi*sig).^2/2);
%% [EOF] - normchr
    

    
