function pv=normvdf(V,sig,mu)
%NORMVDF Probability Density Function of the normal distribution
%        German: Verteilungsdichtefunktion (vdf)
%
%   Syntax
%   pv=normvdf(V)
%   pv=normvdf(V,sig)
%   pv=normvdf(V,sig,mu)
%
%   Description
% pv=normvdf(V) calculates the desnsity function of the normal
%   distribution for random values V, using the default parameters sig=1 
%   and mu=0.
% pv=normvdf(V,sig,mu) calculates the density for a random signal with a 
%   standard deviation sig and a mean value mu.
%
%   References: [DSV1, chap. 3.1.1, p. 135]
%
%   See also MATLAB: randn 
%            DSV_Lib: normchr, rectvdf, chi2vdf, stuvdf, rayvdf, 
%                  expvdf, sinvdf, binvdf

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(1,3, nargin, 'struct'))
%
if nargin<2, sig=1; end
if nargin<3, mu =0; end
%
pv=exp(-(V-mu).^2./(2*sig*sig))./(sig*sqrt(2*pi));
%% [EOF] - normvdf
