function y=randbin(n,p)
%RANDBIN Random sequence, having discrete binominal distributed values  
%   The random numbers are binominal or Bernoulli distributed.
%
%   Syntax
%    y=randbin(n,p)
%
%   Description
% y=randbin(n,p)outputs a sequence of length n, having values 0 and 1 only.
%   The probability for a "one" is p and that for a "zero" is 1-p.
%
%   The random numbers are internally generated by RAND. Therefore the 
%   random generator can be backouted by RAND('state',0), see  description
%   of RAND.
%
%   References: [DSV1, p.137], [Pap91]
%
%   See also MATLAB: rand, randn, 
%            DSV-Lib: randch2, randchi2, randexp, randray, randrect, randstu

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(2,2, nargin, 'struct'))
%
if nargin<2, p=0.5; end
y=round(rand(n,1)+p-0.5);
%% [EOF] - randbin    
