function y=randchi2(ir,ic,nf)
%RANDCHI2 Random sequence with chi^2-distribution
%   Chi^2-distributed random numbers are calculated for the 
%   matrix y(ir,ic). Chi2-distributions degree of freedom is given
%   by the parameter nf.
%
%   Syntax
%   y=randchi2(ir,ic,nf)
%
%   Description
%  y=randchi2(ir,ic,nf) calculates the random numbers stored in
%   a matric of size ir,ic.
%
%   References: [DSV1, p.136], [Pap91]
%
%
%   See also MATLAB: rand, randn, 
%           DSV-Lib: randbin, randexp, randray, randrect, randsin, randstu
%           

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek to H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(3,3, nargin, 'struct'))
%
if nf<1 || ~rem(nf,1)==0,         % check for integer
    error('randchi2: parameter n integer > 0?'); end
y=zeros(ir,ic);
for i=1:nf,
    y=y+randn(ir,ic).^2;
end
%% [EOF] - randchi2    
