function y=randexp(ir,ic,alpha)
%RANDEXP Random sequence, having exponential distribution
%
%   Syntax
%   y=randexp(ir,ic)
%   y=randexp(ir,ic,alpha)
%
%   Description
% y=randexp(ir,ic)outputs an ir by ic matrix of exponential distributed 
%   random numbers. Parameter alpha is set to 1. by default. 
% y=randexp(ir,ic,alpha) produces random numbers with an exponential 
%   distribution guides by parameter alpha.
%   The random numbers are internally generated by rand(.). Therefore the 
%   random generator can be backouted by rand('state',0), see description
%   of rand(.).
%
%   References: [DSV1, p.143], [Pap91]
%
%   See also MATLAB: rand, randn, 
%           DSV-Lib: randbin, randch2, randray, randrect, randsin, randstu  

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(2,3, nargin, 'struct'))
%
if nargin<3, alpha=1.; end
v=rand(ir,ic);
y=-1/alpha*log(1-v);
%% [EOF] - randexp