function y=randray(ir,ic,alpha)
%RANDRAY Random sequence, having Rayleigh distribution
%
%   Syntax
%   y=randray(ir,ic)
%   y=randray(ir,ic,alpha)
%
%   Description
%   y=randray(ir,ic)outputs an ir by ic matrix of Rayleigh distributed 
%   random numbers. The parameter alpha is set to alpha = 1 by default.
%   y=randray(ir,ic,alpha) produces a Rayleigh distribution with variable
%   parameter alpha.
%   The random numbers are internally generated by RAND. Therefore the 
%   random generator can be backouted by RAND('state',0), see  description
%   of rand(.).
%   
%   References: [DSV1, p.142], [Pap91]
%
%   See also MATLAB: rand, randn, 
%            DSV-Lib: randbin, randch2, randexp, randrect, randsin, randstu

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%  ---------------------------------------------------------------
error(nargchk(2,3, nargin, 'struct'))
%
if nargin<3, alpha=1.; end
v=rand(ir,ic);
y=abs(alpha)*sqrt(-2*log(v));
%% [EOF] - randray