function y=randrect(ir,ic,V1,V2)
%RANDRECT Random sequence, having uniform (rectangular) distribution
%
%   Syntax
%   y=randrect(ir,ic,V)
%   y=randrect(ir,ic,V1,V2)
%
%   Description
% y=randrect(ir,ic,V)outputs an ir by ic matrix of symmetric and constant
%   distributed random numbers. The random values are beteen -V and +V.
%
% y=randrect(ir,ic,V1,V2) produces a constant distribution of values
%   beteen V1 and V2. 
%   The random numbers are internally generated by RAND. Therefore the 
%   random generator can be backouted by RAND('state',0), see description
%   of rand(.).
%
%   References: [DSV1, p.142]
%
%   See also MATLAB: rand, randn, 
%           DSV-Lib: randbin, randexp, randch2, randray, randsin, randstu     

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek for H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(3,4,nargin, 'struct'))
%
if nargin<4, V2=V1; V1=-V1; end
Vm=(V1+V2)/2; V0=(V2-V1);
y=rand(ir,ic);
y=V0*(y-0.5)+Vm;
%% [EOF] - randrect
