function y=randsin(ir,ic,a)
%RANDSIN Random sequence, having sinusoidal distribution
%
%   Syntax
%   y=randsin(ir,ic)
%   y=randsin(ir,ic,a)
%
%   Description
% y=randsin(ir,ic)outputs an ir by ic matrix of sinusoidal distributed 
%   random numbers. The amplitude a is set to 1. by default.
% y=randsin(ir,ic,a) produces random numbers with sinusoidal distri- 
%   bution and an amplitude a.
%   The random numbers are internally generated by RAND. Therefore the 
%   random generator can be backouted by RAND('state',0), see  description
%   of RAND.
%
%   References: [DSV1, p.143], [Pap91]
%
%   See also MATLAB: rand, randn, 
%           DSV-Lib: randbin, randch2, randexp, randray, randrect, randstu  

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek for H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(2,3,nargin, 'struct'))
%
if nargin<3, a=1.; end
v=rand(ir,ic);
y=a*sin(pi*(v-0.5));
%% [EOF] - randsin