function y=randstu(ir,ic,n)
%RANDSTU Random sequence, having "Student" distribution
%
%   Syntax
%   y=randstu(ir,ic,n)
%
%   Description
% y=randstu(ir,ic,n)outputs a ir by ic matrix of "Student" distributed 
%   random numbers.
%   The random numbers are internally generated by RANDN. Therefore the 
%   random generator can be backouted by RANDN('state',0), see  description
%   of RAND.
%   
%   References:  [DSV1, p.136], [Pap91]
%
%   See also MATLAB: rand, randn, 
%            DSV-Lib: randbin, randch2, randexp, randray, randrect, randsin

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek for H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(3,3, nargin, 'struct'))
%
% Chi2-Verteilung mit Freiheitsgrad n
v2=zeros(ir,ic);
for i=1:n,
    v2=v2+randn(ir,ic).^2;
end
% Studentsche-Verteilung
y=randn(ir,ic)./sqrt(v2/n);
%% [EOF] - randstu    
