function pv=rayvdf(V,alpha)
%RAYVDF  Probability density function  of the Rayleigh distribution
%        German: Verteilungsdichtefunktion (vdf)
%
%   Syntax
%   pv=rayvdf(V)
%   pv=rayvdf(V,alpha)
%
%   Description
% pv=rayvdf(V) calculates the probability density function pv 
%   of the Rayleigh distribution with parameter alpha=1. The density 
%   function is computed for the abscissa values given in vector V.
%
% pv=rayvdf(V,alpha) calculates the density distribution for variable
%   parameter alpha.
%
%   References: [DSV1, Chap. 3.1.2, p. 143],[Pap91]
%
%   See also DSV_Lib: randray, normvdf, rectvdf, chi2vdf, stuvdf, expvdf, 
%                     sinvdf, binvdf

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek for H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(1,2, nargin, 'struct'))

if nargin<2, alpha=1; end
V=V(:);
pv= zeros(size(V));
ind=find(V>=0);
alp2=alpha^2;
pv(ind)=V(ind)/alp2.*exp(-V(ind).^2/2/alp2);
%% [EOF] - rayvdf
