function C=rectchr(chi,V1,V2)
%RECTCHR Characteristic Function of a uniform dist. sequence
%   Calculation of the characteristic function of a uniform (rectangular)
%   distributed random signal
%
%   Syntax
%   C=rectchr(chi,V)
%   C=rectchr(chi,V1,V2)
%
%   Description
% C=rectchr(chi,V) calculates the characteristic function C(chi) for the 
%   distribution v=[-V,V] or v=[V(1),V(2)]. chi is the vector containing
%   the frequency values for the determination of the function.
% C=rectchr(chi,V1,V2)the characteristic function C (chi)is calculated for a 
%   asymetric distribution of random numbers in the range (V1, V2).
%
%   References: [DSV1, Chap. 3.1.3 p.145 ff]
%
%   See also DSV-Lib: randrect, rectvdf, normchr, chi2chr, stuchr, raychr, 
%                     expchr, sinchr, binchr
%            Matlab:  rand
 
%%  ---------------------------------------------------------------
%   DSV1-Bibliothek for H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(2,3, nargin, 'struct'))
if nargin<3,
    if length(V1)==1, V2=V1;    V1=-V1;
    else              V2=V1(2); V1=V1(1);
    end
end
if V2<V1, error('rectchr: Parameter Error ?'); end
if V2==-V1,              % Symmetric distribution
    C = sinc(chi*V1/pi); % real function
else                     % complex function
    chip=chi*(V2+V1)/2; 
    sic =sinc(chi*(V2-V1)/2/pi); 
    Re= cos(chip).*sic;
    Im= sin(chip).*sic;
    C=complex(Re,Im);
end
%% [EOF] - rectchr
    

    
