function pv=rectvdf(V,V1,V2)
%RECTVDF Probability density function of the uniform distribution
%        German: Verteilungsdichtefunktion (vdf)
%
%   Syntax
%   pv=rectvdf(V,V1)
%   pv=rectvdf(V,V1,V2)
%
%   Description
% pv=rectvdf(V,V1) calculates the probability density function pv 
%   of the uniform (rectangular) distribution beteen -V1 and +V1. The
%   density function is returned for the values of vector V.
% pv=rectvdf(V,V1,V2)processes the density function for an unsymmetrical 
%   uniform distribution of random values between V1 and V2.
%
%   References: [DSV1, chap. 3.1.2, p. 142]
%
%   See also DSV_Lib: randrect, normvdf, chi2vdf, stuvdf, rayvdf, expvdf, 
%                     sinvdf, binvdf

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek for H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(2,3, nargin, 'struct'))
%
if nargin<3, V2=-V1; V1=-V1; end

pv=zeros(size(V));
pmax=1/(V2-V1);
ind=find(V>=V1 & V<V2);
pv(ind)=pmax;
%% [EOF] - rectvdf

