function C=sinchr(chi,a)
%SINCHR Characteristic function of a sinusoidal distributed sequence
%
%   Syntax
%   C=sinchr(chi)
%   C=sinchr(chi,a)
%
%   Description
% C=sinchr(chi) calculates the characteristic function for the 
%   sinusoidal distribution with an amplitude a=1. 
%   The function is  computed for the values of vector chi.
%
% C=sinchr(chi,a) In addition we use a selectivable amplitude parameter a.
%
%   References: [DSV1, Chap. 3.1.3 p.145 ff]
%
%   See also DSV-Lib: randsin, sinvdf, normchr, rectchr, chi2chr, raychr, 
%                     stuchr, expchr,  binchr

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek for H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(1,2,nargin, 'struct'))
%
if nargin<2, a=1.; end
%
[C,ierr]=besselj(0,a*chi);
C=real(C);
if ierr~=0, error('sinchr: see besselj Error return code'); end
%% [EOF] - sinchr