function pv=sinvdf(V,a)
%SINVDF  Probability density function  of the siusoidal distribution
%        German: Verteilungsdichtefunktion (vdf)
%
%   Syntax
%   pv=sinvdf(V)
%   pv=sinvdf(V,a)
%
%   Description
% pv=sinvdf(V) calculates the probability density function pv 
%   of the sinusoidal distribution with amplitude a=1. The density 
%   function is computed for the abscissa values given in vector V.
%
% pv=sinvdf(V,a) calculates the density distribution for variable
%   amplitude a.
%
%   References: [DSV1, Chap. 3.1.2, p. 142],[Pap91]
%
%   See also DSV_Lib: randsin, normvdf, rectvdf, chi2vdf, stuvdf, expvdf, 
%                     rayvdf, binvdf

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek for H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(1,2, nargin, 'struct'))
%
if nargin<2, a=1.; end
pv= zeros(size(V));
ind=find(abs(V)<a);
pv(ind)=1/pi/a./sqrt(1-(V(ind)./a).^2);
% Calculate rim cases for sum of pv < 1
gV=gradient(V);  del=1-sum(pv.*gV);
id1=ind(1)-1; id2=ind(end)+1;
pv([id1,id2])=del/2./gV([id1,id2]);
%% [EOF] - sinvdf
