function C=stuchr(chi,nf)
%STUCHR Characteristic function of a Student-distributed sequence
%
%   Syntax
%   C=stuchr(chi,nf)
%
%   Description
% C=stuchr(chi,nf) calculates the characteristic function for the 
%   Student-distribution with degree of freedom nf. The function is 
%   computed for the values of vector chi. 
% 
%   References: [DSV1, Chap. 3.1.3 p.145 ff]
%
%   See also DSV-Lib: randstu, stuvdf, normchr, rectchr, chi2chr, raychr, 
%                     expchr, sinchr, binchr

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek for H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(2,2, nargin, 'struct'))
%
if nf<1 || ~rem(nf,1)==0,         % check for integer
    error('chi2chr: parameter nf integer > 0?'); end
%
nu=nf/2;  sqn=sqrt(nf);
chi_=abs(chi);
chi_(chi_==0)=eps;
C=2^(1-nu)/gamma(nu)*(sqn*chi_).^nu.* besselk(nu,sqn*chi_);
%% [EOF] - stuchr

