function pv=stuvdf(V,n)
%STUVDF  Probability density function  of the Student distribution
%        German: Verteilungsdichtefunktion (vdf)
%
%   Syntax
%   
%
%   Description
%   pv=stuvdf(V,n) calculates the probability density function pv 
%   of the Student distribution for the summation of n independent uniform 
%   random signals. The density function is computed for the abscissa
%   values given in vector V.
%
%   References: [DSV1, Chap. 3.1.2, p. 136],[Pap91]
%
%   See also DSV-Lib: randstu, normvdf, rectvdf, chi2vdf, rayvdf, expvdf, 
%                     sinvdf, binvdf
%            MATLAB:  gamma

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek for H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(2,2, nargin, 'struct'))
%
nh=n/2;  n1=(n+1)/2;
fac=gamma(n1)/(sqrt(n*pi)*gamma(nh));
% Studentsche-Verteilungsdichte
pv=fac*(1+V.^2/n).^-n1;
%% [EOF] - stuvdf


