function pvx=xpdf(v,Vn)
%XPDF: Estimation of the one-dimensional distribution density
%   The distribution density is generated by calculation of the 
%   histogram for equidistant bins, according to vector Vn
%
%   Syntax
%   pvx=xpdf(v,Vn)
%
%   Description
% pvx=xpdf(v,V) returns the distribution density of sequence v 
%   among length(Vn) bins with centers specified by Vn
%
%   References: [DSV1, Chap. 3.3.3 p.184 ff]
%   See also DSV-Lib: xpdf2
%            Matlab:  hist

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek for H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(2,2, nargin, 'struct'))
%
[hi,V]=hist(v,Vn);
dV=Vn(2)-Vn(1);  N=length(v);
pvx=hi/N/dV;
%% [EOF] - xpdf