function p12=xpdf2(v1,v2,V1,V2)
%XPDF2: Estimation of the two-dimentional distribution density
%   The distribution density p12 is generated in two steps. At first the 
%   histograms for both sequences v1 and v2 are calculated at equidistant 
%   bins, according to the vectors V1 and V2. In a second step the two-
%   dimensional density matrix is calculated out of the index matrix, 
%   generated together with the histograms, by searching .
%
%   Syntax
%   p12=xpdf2(v1,v2,V1,V2)
%
%   Description
% p12=xpdf2(v1,v2,V1,V2)generates the two-dimensional distribution density
%   matrix for the two random sequences v1 and v2. The limits of the matrix
%   are given in the vectors V1 and V2.
%
%   References: [DSV1, Chap. 3.1.4 p.154 ff]
%
%   See also DSV-Lib: xpdf
%            Matlab:  hist, histc, find
%
%%  ---------------------------------------------------------------
%   DSV1-Bibliothek for H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(4,4, nargin, 'struct'))
%
[hi1,bin1]=histc(v1,V1);  nV1=length(V1);
[hi2,bin2]=histc(v2,V2);  nV2=length(V2);
%
h=zeros(nV1,nV2);
for i=1:nV1,
    h1=find(bin1==i);
    for j=1:nV2,
      h(i,j)=sum(bin2(h1)==j); 
    end
end
N=length(v1); fac=1/N/(V1(2)-V1(1))/(V2(2)-V2(1));
p12=fac*h(1:end-1,1:end-1);
%% [EOF] - xpdf2