function CAP1=cap2casos(CAP,str)
%CAP2CASOS Determing coefficients for the substructures of coupled allpass 
%
%   Syntax
%   CAP1=cap2casos(CAP)
%   CAP1=cap2casos(CAP,str)
%
%   Description
%   ---------- in preparation ----------------
%                             
%   References: [DSV1, chap. 6.6.3 and 7.1.3]
%
%   See also DSV-Lib: sos2casos, tf2catf

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(1,2, nargin, 'struct'))
typ=CAP.name;
CAP1=CAP;
if nargin<2, str='df1sos'; end
CAP1.name ='Coupled allpass in SOS form';
switch str
   case {'df1sos','df1tsos','df2sos','df2tsos','lfssos'},
     CAP1.substr=str;
   otherwise,  error('CAP2CASOS: not allowed substructure');
end
%% Check input / output structure
 SOS=cell(2); S=cell(2);
if ~isempty(strfind(typ,'direct form'))  % CAP: CATF structure
    for i=1:2,
      b=CAP.coef{i}(1,:); a=CAP.coef{i}(2,:);
      [sos,s]=tf2sos(b,a);
      SOS{i}=sos; S{i}=s;
    end
elseif ~isempty(strfind(typ,'lattice form'))  % CAP: CALATstructure
    for i=1:2
      rc=CAP.coef{i}
      [b,a]=latc2tf(rc,'allpass');
      [sos,s]=tf2sos(b,a);
      SOS{i}=sos; S{i}=s;
    end
elseif ~isempty(strfind(typ,'SOS form'))  % CAP: CASOS structure
    if strcmp('lfssos',CAP.substr )
       if strcmp('lfssos',CAP1.substr), return; end
       for i=1:2
          lfs=CAP.coef{i}{1};
          nb=size(lfs,1);
          sos=zeros(nb,6);
          for n=1:nb
             if lfs(n,1)~=0
                c0=lfs(n,1); 
                sos(n,4:6)=[1,lfs(n,2)*(1+c0),c0];
                sos(n,1:3)=fliplr(sos(n,4:6));
             else
                sos(n,4:6)=[1,lfs(n,2),0];
                sos(n,1:3)=[fliplr(sos(n,4:5)),0];
             end
          end
          SOS{i}=sos; S{i}=1;
       end
    else
        for i=1:2
        SOS{i}=CAP.coef{i}{1}; S{i}=CAP.coef{i}{2};
        end
    end
else error('CAP2CASOS: CAP structure not defined')
    
end
%% Build final CASOS coefficients
   for i=1:2,
       sos=SOS{i}; s=S{i};
     nb=size(sos,1);
     for n=1:nb                % set to unscaled allpass coefficients
         if sos(n,3)~=0, fac=sos(n,3);
         else fac=sos(n,2);    
         end
         sos(n,1:3)=sos(n,1:3)/fac;
         s=s*fac;
     end
     switch str
         case 'lfssos'         % build LFS-dataset
                     lfs=sos2lfs(sos,s);
                     CAP1.coef{i}={lfs};
         otherwise,  CAP1.coef{i}={sos,s};
     end
  end

%% [EOF] cap2casos
