function [b,c]=cap2tf(CAP)
%CAP2TF Transformation of coupled allpass coefficients to transfer function
%
%   Syntax
%   [b,c]=cap2tf(CAP)
%
%   Description
%   ---------- in preparation ----------------
%                             
%   References: [DSV1, chap. 6.6.3 and 7.1.3]
%
%   See also DSV-Lib:  tf2catf

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.01   Release 2010_2
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(1,1, nargin, 'struct'))
%
typ=CAP.name;
if ~isempty(strfind(typ,'direct form'))  % CAP: CATF structure
    % Coefficients already in CAP
else 
    CAP=cap2catf(CAP);
end
%% Check for complex coupled allpass structure
if isempty(strfind(typ,'complex'))  % real structure
    % Parallel Connection of the two branches
    num1=CAP.coef{1}(1,:); den1=CAP.coef{1}(2,:);
    num2=CAP.coef{2}(1,:); den2=CAP.coef{2}(2,:);
    fac =CAP.coef{3};
    %
    b = fac/2*(conv(num1,den2)+conv(num2,den1));
    c = conv(den1,den2);
else                                 % complex structure
    psi =CAP.coef{2}; 
    numa=psi*CAP.coef{1}(1,:);   
    numa_ = conj(numa); 
    dena=CAP.coef{1}(2,:);   
    dena_ = conj(dena);
    fac  = CAP.coef{3};
    %
    b = fac/2*real((conv(numa,dena_) + conv(numa_,dena)));
    c = real(conv(dena,dena_));
end
%% [EOF] - cap2tf
        
        
