function Z2 = compltf(Z1,D)
%COMPLTF: Calculate complementary transfer function for coupled allpasses
%
%   Syntax
%   Z2 = compltf(Z1,D)
%
%   Description
% Z2 = compltf(Z1,D)calculates the numerator of the complementary transfer 
%   function Z2 to
%   the original transfer function defined by the numerator Z1 and the 
%   denominator D.
%
%   References: [DSV1, chap. 6.6.3]
%   See also DSV-Lib: tf2catf, sos2calfssos
%            Matlab:  cov

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Hans W. Schssler
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(2,2,nargin))
%
n = length(D)-1; m = ceil((n-1)/2);
A = conv(Z1,Z1) - conv(D,fliplr(D));
if (rem(n,2) == 0), A = -A; end;
% Rekursive Berechnung der ersten Haelfte der Koeffizienten
Z2 = [sqrt(A(1)) zeros(1,m)];
for mu = 2:m+1,
   Z2temp = Z2(2:mu-1);
   Z2(mu) = (A(mu)-sum(Z2temp.*fliplr(Z2temp)))/(2*Z2(1));
end
% Ergaenzung der hoeheren Koeffizienten
if (rem(n,2) == 0),
    Z2 = [Z2 fliplr(Z2(1:m))];
else
    Z2 = -[Z2 -fliplr(Z2)];
end
%% [EOF] - compltf
