function [b,c]=lfssos2tf(lfs,s)
%LFSSOS2TF Transfer lattice coefficients back to transfer function
%
%   Syntax
%   [b,c]=lfssos2tf(lfs)
%   [b,c]=lfssos2tf(lfs,s)
%
%   Description
%   ---------- in preparation ----------------
%                             
%   References: [DSV1, chap. 6.2 and 7.1.3.1]
%
%   See also DSV-Lib:  sos2lfs, print_lfs 
%            Matlab:   sos2tf

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(1,2, nargin, 'struct'))
if nargin<2, s=1; end

%% Build SOS Allpass sections
  nn=size(lfs,1);
  for i=1:nn
    c0=lfs(i,1);
    if lfs(i,2)~=0,
      c1=lfs(i,2)*(1+c0);
      soc(i,1:6)=[c0,c1,1,1,c1,c0];
    else
      soc(i,1:6)=[c0,1,0,1,c0,0]
    end
  end
%% Build Transferfunction
[b,c] = sos2tf(soc,s);
%% [EOF] - lfssos2tf
