function [r,N] = p2latc(c)
%P2LATC Reflection coefficients for lattice structure
%   Calculation of the reflection coefficients according to "Schur-Chon"
%
%   Syntax
%   [r,N] = p2latc(c)
%
%   Description
%   The reflection coefficients are calculated for the denominator vector
%   c.
%   Optionally available is the internal matrix N, see references. 

%   References: [DSV1, chap. 5.5.1 and 6.7]
%
%   See also Matlab: tf2latc, sysstable

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Author: Hans W. Schuessler
%   Version: 1.0
%   Copyright 2007 by author(s) - not released for commercial use
%  ---------------------------------------------------------------
error(nargchk(1,1,nargin))
%
c = c(:)'; n1 = length(c); r = []; N = c;
for i = n1:-1:2;
  ri = c(i);
   r = [r ri];                              %#ok<AGROW>
   c = (c(1:i-1) - ri*c(i:-1:2))/(1-ri^2);
   N = [N;[zeros(1,n1+1-i) c]];             %#ok<AGROW>
end
r=fliplr(r)';
%% [EOF] - p2latc
