function sops=par2par(sop,sp)
%PAR2PAR Transformation of parallel forms 
%        Transformation parallel form of 1. kind (Jackson) to
%        to the 2. kind (Schuessler) and vice versa
%
% sops=par2par(sop)transforms the SOP-matrix of one kind into that of the
%   other kind
%
% sops=par2par(sop,sp)optionally multiplies first scalingfactors for fixed point
%   realization into the SOP-matrix and than transforms the Matrix to the
%   other kind of parallel forms
%   Remark: Scaling a parallel form for fixed point realization is not included 
%   in the current release of the DSV-Library
%
%   References: [DSV1, chap. 5.2]
%
%   See also DSV-Lib: sos2par, par2sos, zp2par, par2zp 

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(1,2, nargin, 'struct'))
nb=size(sop,1)-1;
sops=sop;
if  sop(nb+1,2:3)~=0, error('PAR2PAR: error in SOP dataset'); end
ds=sop(nb+1,1);
if nargin >1,
    [s1,s2,s3]=parse_sp(sp,nb);
    ss=[s2,s2,s2];
    sop(1:nb,1:3)=s1*s3*(ss.*sop(1:nb,1:3));
    ds = s1*s3*ds;
end
%%
if sop(:,3)==0,
for i=1:nb              % transfer to 1. kind
    sops(i,1)=0.;
    sops(i,2) = sop(i,2)-sop(i,1)*sop(i,5);
    sops(i,3) = -sop(i,1)*sop(i,6);
    ds = ds +sop(i,1);
end
elseif sop(1:nb,1)==0,
for i=1:nb,             % transfer to 2. kind
    if sop(i,6) ~=0,
      d0=-sop(i,3)/sop(i,6);
      sops(i,2)= sop(i,2)+d0*sop(i,5);
    else
      d0=-sop(i,2)/sop(i,5);
      sops(i,2)=0;
    end
    sops(i,1)=d0;
    sops(i,3)=0.;
    ds = ds - d0;
end
else
    error ('PAR2PAR: not a numerator for Parallel Form')
end
sops(nb+1,1)=ds;
%% Helper Function
function [s1,s2,s3]=parse_sp(sp,nb)
if ~isempty(sp)
    terr='PAR2PAR: mismatched scaling parameters';
  [Lsp,Csp]=size(sp);
  switch Csp,
  case 3
    if Lsp~=nb, error(terr); end
    s1=sp(1,1); s2=sp(1:nb,2); s3=sp(1,3);
  case 2
    if Lsp~=1, error(terr); end
    s1=sp(1,1); s2=ones(nb,1); s3=sp(1,2);
  case 1
    if Lsp~=nb, error(terr); end
    s1=1; s2=sp; s3=1;
  otherwise,    error(terr)
  end
else
    s1=1; s2=ones(nb,1); s3=1;
end
%% [EOF] - par2par
