function [sos,s] = par2sos(varargin)
%PAR2SOS Transformation of parallel form (SOP) to SOS
%    The parallel form (SOP) may be available in the 1. or 2. kind.
%
% [sos,s] = par2sos(sop)transforms the coefficient matrix sop back to the
%   general sos form. The normalized coefficients are returned in the 
%   matrix sos and the total gain in the factor s. 
%
% [sos,s] = par2sos(sop,sp) optionally, includes scaling factors, used
%   together with fixed point realizations.
%   Remark: Scaling a parallel form for fixed point realization is not included 
%   in the current release of the DSV-Library
%
%   References: [DSV1, chap. 5.2]
%   See also DSV-Lib: sos2par, par2zp
%            Matlab:  zp2sos

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(1,2,nargin))
%
[z,p,k] = par2zp(varargin{:});
[sos,s] = zp2sos(z,p,k);
%% [EOF] - par2sos
