function [b,c]=par2tf(varargin)
% PAR2TF: Transformation from parallel form to transfer function (direct form)      
%    The parallel form (sop) may be used in the 1. or 2. kind.
%
% [b,c] = par2tf(sop)transforms the coefficient matrix sop into the
%   direct form, described by the transferfunction parameters [b,c]. 
%
% [b,c] = par2sos(sop,sp) the optionally included scaling factors sp, used
%   together with fixed point realizations, are  multiplied to the 
%   sop-matrix and transfered back to the direct form.
%   Remark: Scaling a parallel form for fixed point realization is not included 
%   in the current release of the DSV-Library

%   References: [DSV1, chap. 5.2]
%   See also DSV-Lib: par2zp, par2sos, tf2par
%            Matlab:  zp2tf

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(1,2,nargin))
[z,p,k]=par2zp(varargin{:});
[b,c]  =zp2tf(z,p,k);
%% [EOF] - par2tf







