function print_cap (varargin)
%PRINT_CAP Prints CAP structure for coupled allpasses
%
%   Syntax
%   print_cap(CAP)
%   print_cap(cn,CAP)
%
%   Description
% print_cap(CAP) prints the CAP-structure at the standard Matlab output channel
%
% print_cap(cn,...)prints the output on channel cn
%
%   References: [DSV1, chap. 6.6.3 and 7.1.3]
%   See also DSV-Lib:  tf2catf, cap2tf, cap2calat, cap2catf, cap2casos
%            Matlab:   fprintf

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Author: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by author(s) - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(1,2,nargin))
argin=varargin;  %Parse input
fid=argin{1};
if   isscalar(fid)&&~isstruct(fid), argin=argin(2:end);  
else fid=1;
end
CAP=argin{1};
%%
fprintf (fid,'\n\n CAP-Structure')
fprintf (fid,'\n  Filter Type: %s',CAP.name)
fprintf (fid,'\n Substructure: %s-form',CAP.substr)
fprintf (fid,'\n  Total Order: %3d',CAP.order)
fprintf (fid,'\n Scale Factor: %9.6f',CAP.coef{3})
%%
  typ=CAP.name;
  if  ~isempty(strfind(typ,'direct form')),
      for i=1:2,
fprintf (fid,['\n Coefficients of ',int2str(i),'. Subsystem:'])
         num=CAP.coef{i}(1,:); den=CAP.coef{i}(2,:);
fprintf (fid,'\n       Order: %3d',length(den)-1)
fprintf (fid,'\n   Numerator: ')
fprintf (fid,'\n      %9.6f   %9.6f   %9.6f   %9.6f',num)
fprintf (fid,'\n Denominator: ')
fprintf (fid,'\n      %9.6f   %9.6f   %9.6f   %9.6f',den)
      end
  elseif ~isempty(strfind(typ,'SOS form')),
fprintf (fid,'\n\n')
      for i=1:2,
fprintf (fid,['\n Coefficients of ',int2str(i),'. Subsystem:']) 
        switch CAP.substr
           case 'lfssos'
               lfs=CAP.coef{i}{1}; 
print_lfs(lfs)
           otherwise
              sos=CAP.coef{i}{1}; s=CAP.coef{i}{2};
print_sos(sos,s)
        end
      end
 elseif ~isempty(strfind(typ,'lattice form')),  
     for i=1:2,
fprintf (fid,['\n Reflection Coefficients of ',int2str(i),'. Subsystem:']) 
     r=CAP.coef{i};
fprintf (fid,'\n      %9.6f   %9.6f   %9.6f   %9.6f',r)
     end
 else error ('PRINT_CAP: Filter Type not defined');
  end
fprintf (fid,'\n\n')
%% [EOF] - print_cap
