function print_lfs (varargin)
%PRINT_LFS Prints coefficients of lattice structure (LFS Form)
%
%   Syntax
%   print_lfs(lfs)
%   print_lfs(lfs,s)
%   print_lfs(cn,lfs,...)
%
%   Description
%
% print_lfs(lfs) prints the lattice coefficients at the standard Matlab 
%   output channel
%
% print_lfs(lfs,s)prints in addition the scaling factors s for the 
%   lattice structure
%  
% print_lfs(cn,...)prints the output on channel cn
%
%   References: [DSV1, chap. 6.2 and 7.1.3.2]
%
%   See also DSV-Lib: sos2lfs, p2latc 
%            Matlab:  fprintf, tf2latc

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Author: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by author(s) - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(1,3,nargin))
argin=varargin;  %Parse input
fid=argin{1};
if   isscalar(fid), argin=argin(2:end);  
else fid=1;
end
lfs=argin{1};
if length(argin) < 2, s=1; 
else           s=argin{2}; end
%%
  [nb,nr] = size(lfs);
fprintf (fid,'\n Filter in LFS Form')
  if nb==1, 
fprintf (fid,'\n Lattice Structure: %2d blocks of first order',nr)
fprintf (fid,'\n\n   r(1)    ...   r(n)')
fprintf (fid,'\n    %9.6f',lfs)
  else    
fprintf (fid,'\n Cascaded Lattice Structure of\n %2d second order blocks',nb); 
fprintf (fid,'\n\n')
fprintf (fid,'    (i)    alpha(i)    betha(i)  \n');
    for i = 1:nb
fprintf (fid,'    (%2d)  %9.6f    %9.6f \n',i,lfs(i,:));
    end
  end
fprintf (fid,'\n Additional scaling factor: %9.6f',s);
fprintf (fid,'\n\n')
%% [EOF] - print_lfs
