function print_par(varargin)
%
%   Syntax
%   print_par(sop)
%   print_par(sop,sp)
%   print_par(cn,sop,sp)
%
%   Description
% PRINT_PAR Prints coefficients of the parallel structure   
%
% print_par(sop) prints the SOP-matrix at the standard Matlab output channel
%
% print_par(sop,sp)prints in addition the scaling factors of the parallel form,
%   passed by vector sp
% print_par(cn,...)prints the output on channel cn
%
%   Remark: Scaling a parallel form for fixed point realization is not included 
%   in the current release of the DSV-Library
%
%   References: [DSV1, chap. 5.2.2 and 7.1.3.2]
%
%   See also DSV-Lib: tf2par, zp2par, sos2par
%            Matlab:  fprintf

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(1,3,nargin))
argin=varargin;  %Parse input
fid=argin{1};
if   isscalar(fid), argin=argin(2:end);  
else fid=1;
end
sop=argin{1}; 
if length(argin) < 2, lsc=false;ts='no scaling'; sp=[];
else                  lsc=true; ts = []; sp=argin{2};
end
%%
nb = size(sop,1)-1;
if  sop(nb+1,2:3)~=0, error('SOP2SOP: error in SOP dataset'); end
if sop(:,3)==0, kind=2; tx='g_n'; else  kind=1; tx='b_n'; end

fprintf (fid,['\n Filter in SOP Form  ',int2str(kind),'. Kind'])
fprintf (fid,'\n Number of SOP Blocks:'); fprintf(fid,'%2d',nb) 
fprintf (fid,'\n\n')
fprintf (fid,'      B2        B1        B0                     C1        C0 \n');
fprintf (fid,'      b0i       b1i       b2i          a0i       a1i       a2i\n');
%
for i = 1:nb
    fprintf (fid,'(%2d)%9.6f %9.6f %9.6f    %9.6f %9.6f %9.6f\n',i,sop(i,:));
end
fprintf (fid,['\n Direct Branch ',tx,' =%11.6f\n'],sop(nb+1,1));
fprintf (fid,['\n Scaling:  ',ts]);
if lsc
    if size(sp,2)==1, sp1=1.; sp2=sp; sp3=1.;
    else              sp1=sp(1,1); sp2=sp(:,2); sp3=sp(1,3);
    end
    fprintf (fid,'\n Prescaling Factor  =%11.6f',sp1)
    fprintf (fid,'\n Block Scaling Factors:'); 
    for i=1:nb
       fprintf(fid,'\n              (%2d)  %12.6f ',i,sp2(i))
    end
    fprintf (fid,'\n Postscaling Factor =%11.6f',sp3)
end
fprintf (fid,'\n\n')
%% [EOF] - print_par
