function print_sos (varargin)
%PRINT_SOS Prints second order sections (SOS)
%
%   Syntax
%   print_sos(sos)
%   print_sos(sos,s)
%   print_sos(cn,sos,s)
%
%   Description
%
% print_sos(sos) prints the SOS-Matrix at the standard Matlab output channel
%
% print_sos(sos,s)prints in addition the scaling factors of the cascade,
%   passed by vector s
% print_sos(cn,...)prints the output on channel cn
%
%   References: [DSV1, chap. 5.2.2 and 7.1.3.2]
%
%   See also DSV-Lib: tf2sos, zp2sos, scaling_df1sos
%            Matlab:  fprintf
%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Author: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by author(s) - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(1,3,nargin))
argin=varargin;  %Parse input
fid=argin{1};
if   isscalar(fid), argin=argin(2:end);  
else fid=1;
end
sos=argin{1};
if length(argin) < 2, s=1; 
else           s=argin{2}; end
if length(s) ==1, lsc=false;ts='no block scaling';
else              lsc=true; ts = []; end
%%
nb = size(sos,1);
fprintf (fid,'\n Filter in SOS Form')
fprintf (fid,'\n Number of SOS Blocks:'); fprintf(fid,'%2d',nb)
if ~lsc,
    fprintf (fid,'\n Scaling Factor  =%11.6f',s),
end
fprintf (fid,'\n\n')
fprintf (fid,'      B2        B1        B0                     C1        C0 \n');
fprintf (fid,'      b0i       b1i       b2i          a0i       a1i       a2i\n');
%
for i = 1:nb
    fprintf (fid,'(%2d)%9.6f %9.6f %9.6f    %9.6f %9.6f %9.6f\n',i,sos(i,:));
end

fprintf (fid,['\n Scaling:  ',ts]);
if lsc,
  fprintf (fid,'\n Block Scaling Factors:'); 
  for i=1:nb
     fprintf(fid,'\n              (%2d)  %12.6f ',i,s(i))
  end
  fprintf (fid,'\n Postscaling Factor =%11.6f',s(nb+1))
end
fprintf (fid,'\n\n')
%% [EOF] - print_sos
