function print_ssf(varargin)
%PRINT_SSF Prints 2. Order Sections in State Space Form
%
%   Syntax:
%   print_ssf(ssf)
%   print_ssf(ssf,ss)
%   print_ssf(cn,...)
%
%   Description
%   SSF-cell-array for the state space matrices
%   ssf = [{A1} {B1} {Ct1} {D1}
%            ...
%          {An} {Bn} {Ctn} {Dn}]
%
%   References: [DSV1, chap. 5.2.2, 6.3 and 7.1.7.6]
%               [Jack96, Deh03]
%   See also DSV-Lib: sos2ssf, par2ssf
%            Matlab:  fprintf

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Author: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by author(s) - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(1,3,nargin))
argin=varargin;  %Parse input
fid=argin{1};
if   isscalar(fid), argin=argin(2:end);  
else fid=1;
end
ssf=argin{1};
if length(argin) < 2, s=1; 
else           s=argin{2}; end
%% 
fprintf (fid,'\nState Space Filter in ')
  nb = size(ssf,1);
  % check cascade or parallel form
  if  ~(isempty(ssf{nb,1})&& isempty(ssf{nb,2})&& isempty(ssf{nb,3})) , 
      form='c';
fprintf(fid,'Cascade Structure')
  else
       form='p';  nb=nb-1;
fprintf(fid,'Parallel Structure ')
  end
%%      
for i=1:nb
   [A,B,Ct,D] = ssf_getblk(ssf,i);
  fprintf (fid,['\nBlock:  ' int2str(i)])
  fprintf (fid,'\n         [ A ]             [ B ]        [ C ]        [ D ]')
  if size(A,1)==1,
  fprintf(fid,'\n\t %10.6f\t\t   %10.6f   %10.6f   %10.6f\n',...
     [A  B Ct D])
  else
  fprintf(fid,'\n%10.6f%10.6f   %10.6f   %10.6f   %10.6f',...
     [A(1,1) A(1,2)  B(1)    Ct(1)      D])
  
  fprintf(fid,'\n%10.6f%10.6f   %10.6f   %10.6f\n'...
     ,[A(2,1) A(2,2)  B(2)    Ct(2)])
  end
end
  switch form
      case 'c'
fprintf (fid,'\nScaling Factor: %10.6f \n',s);
      case 'p'
fprintf (fid,'\nDirect coeffiicient: %10.6f \n',ssf{nb+1,4});
  end
%% [EOF] - print_ssf
