function print_wdf (varargin)
%PRINT_WDF Prints the coefficient matrix for the WDF-Form
%   Wave Digital Filter nach Meerktter
%
% print_wdf(wdf) prints the WDF-Matrix at the standard Matlab output channel
%
% print_wdf(wdf,g)prints in addition the scaling factors of the WDF-Form,
%   passed by vector g
% print_wdf(cn,...)prints the output on channel cn
%
%   References: [DSV1, chap. 6.5.3.5 and 7.1.3.2]
%
%   See also DSV-Lib: sos2wdf, wdf2sos, print_sos, print_par

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Author: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by author(s) - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(2,3,nargin))
argin=varargin;  %Parse input
fid=argin{1};
if   isscalar(fid), argin=argin(2:end);  
else fid=1;
end
wdf=argin{1};
if length(argin) < 2, g=1; 
else           g=argin{2}; end
if length(g) ==1, lsc=false; ts='no block scaling';
else              lsc=true;  ts = []; end
%%
nb = size(wdf,1);
fprintf (fid,'\n Filter in WDF Form')
fprintf (fid,'\n Number of second order WDF Blocks:'); fprintf(fid,'%2d',nb)
if ~lsc,
    fprintf (fid,'\n Scaling Factor  =%11.6f',g),
end
fprintf (fid,'\n\n')
fprintf (fid,['      beta0i    beta1i    beta2i       alpha0i',...
    '   alpha1i   alpha2i\n']);
%
for i = 1:nb
    fprintf (fid,'(%2d)%9.6f %9.6f %9.6f    %9.6f %9.6f %9.6f\n',i,wdf(i,:));
end

fprintf (fid,['\n Scaling:  ',ts]);
if lsc,
  fprintf (fid,'\n Block Scaling Factors:'); 
  for i=1:nb
     fprintf(fid,'\n              (%2d)  %12.6f ',i,g(i))
  end
  fprintf (fid,'\n Postscaling Factor =%11.6f',g(nb+1))
end
fprintf (fid,'\n\n')
%% [EOF] - print_wdf
