function lfs=sos2lfs(sos,s)
%SOS2LFS Transfer SOS structure to cascade of second order allpasses
%
%   Syntax
%   lfs=sos2lfs(sos)
%   lfs=sos2lfs(sos,s)
%
%   Description
%   ---------- in preparation ----------------
%                             
%   References: [DSV1, chap. 6.2 and 7.1.3.1]
%
%   See also DSV-Lib:  lfs2sos, print_lfs 

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(1,2, nargin, 'struct'))
errstr='SOS2LFS: Coefficients don''t match allpass!';
%% Build SOS Allpass sections
if nargin<2, s=1.; end
neps = 1e6 * eps;
%
nb=size(sos,1);  lfs=zeros(nb,2);
for i=1:nb
  c0=sos(i,6);
  if c0~=0,
    b0=sos(i,3); s=s*b0;
    sos(i,1:3)=sos(i,1:3)/b0;
    if max(abs(fliplr(sos(i,1:3)/sos(i,3))-sos(i,4:6))) > neps,
       error(errstr)
    end
    lfs(i,1:2)=[c0,sos(i,5)/(1+c0)];
  else
     b0=sos(i,2); s=s*b0;
    sos(i,1:2)=sos(i,1:2)/b0; 
    if max(abs(fliplr(sos(i,1:2)/sos(i,2))-sos(i,4:5))) > neps,
      error(errstr)
    end  
    lfs(i,1:2)=[0,sos(i,5)];
  end
end
if abs(abs(s)-1) > neps, error([errstr,'  incorrect scaling']); end
%% [EOF] - sos2lfs
