function sop=sos2par(sos,s)
%SOS2PAR: Transformation of SOS to parallel form 2. kind
%   The parallel form of second kind distributes the direct throughput over
%   all parallel sections, see [DSV1, Chapt. 5.2.2]
%
%   Syntax
%   sop=sos2par(sos)
%   sop=sos2par(sos,s)
%
%   Description
% sop=sos2par(sos)transforms the parameters of a cascade of second order
%   sections (sos) to second order blocks in the parallel form (sop).
%   The transformation is carried out via the direct form described by 
%   poles and zeros. For the direct branch an additional block is placed 
%   at the end of the matrix.  
% sop=sos2par(sos,s) includes the scaling factor or the scaling vector s
%   into the calculation of the parallel form.
%   Remark: No additional scaling factors are defined for the output matrix .
%
%   References: [DSV1, chap. 5.2]
%
%   See also DSV-Lib: par2sos, zp2par, par2par, print_par

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(1,2,nargin))
if nargin<2, s=1; end
% Transform to zero / pole description
[z,p,k]= sos2zp(sos,s);
% Calulation of parallel form in extended accuracy 
sop    = zp2par(z,p,k);
%% [EOF] - sos2par
