function [wdf,gg]=sos2wdf(sos,s)
%SOS2WDF: Transfer SOS-matrix to wave digital filter of "Meerkoetter" type
%   The coefficients of the filter are stored in the WDF-Matrix
%
%   Syntax
%   [wdf,gg]=sos2wdf(sos)
%   [wdf,gg]=sos2wdf(sos,s)
%
%   Description
% [wdf,gg] = sos2wdf(sos) transfers the scaled or unscaled SOS-Matrix into
%   the WDF-Matrix. The scaling factor is set to s=1.
%
% [wdf,gg] = sos2wdf(sos,s)transfers the SOS-Matrix with regard to the
%   vector of scaling factos.

%   References: [DSV1, chap. 6.5.3.5 and 7.1.3.2]
%
%   See also DSV-Lib: wdf2sos

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(1,2,nargin))
if nargin<2, g=1.; else g=prod(s); end
%
nb=size(sos,1);
wdf=zeros(nb,6);
for n=1:nb,
    b2=sos(n,1); b1=sos(n,2); b0=sos(n,3); c1=sos(n,5); c0=sos(n,6);
    g=g*b2; b1=b1/b2; b0=b0/b2; b2=1.;
    if sos(n,4)~=1, error('SOS2WDF: c2(n)~=1'); end
    bet0=b2;
    bet1=(b0-b1-b2)/2;
    bet2=(b2-b1-b0)/2;
    ga1 =(c0-c1-1)/2;
    ga2 =(1-c1-c0)/2;
    wdf(n,:)=[bet0,bet1,bet2,1,ga1,ga2];
end
gg=g;
%% [] - sos2wdf
