function [SSp,Ap,Bp,Cp,Dp]=ss2block (A,B,C,D,p)
%SS2BLOCK Build system matrix for block state space realization
%   The system matrix for block realization with a block factor p is 
%   calculated out of the state matrices of the system. 
%
%   Syntax
%   SSp  =  ss2block (A,B,C,D,p)
%   [SSp,Ap,Bp,Cp,Dp]=ss2block (A,B,C,D,p)
%                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   qq
%   References: [DSV1, chap. 6.3 and 7.1.6.6]
%
%   See also Matlab:  tf2ss

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Author: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by author(s) - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(5,5,nargin))
%
Ap = A^p;  Bp=[];
for pp=p-1:-1:0
    Bp=[Bp A^pp*B];             %#ok<AGROW>
end
%
Cp=[];
for pp=0:1:p-1
    Cp=[Cp;C*A^pp];             %#ok<AGROW>
end
%
Dp=D*eye(p);
for py=2:1:p,
    for px=1:py-1,
        Dp(py,px)=C*A^(py-px-1)*B;
    end
end
SSp=[Ap Bp; Cp Dp];
%% [EOF] - ss2block
