function [Ac,Bc,Cc,Dc]=ssf2ssc(SSF,ss)
%SSF2SSC Transformation of cascade of 2. order state space form to SSC
%   SSC State variable description of the cascade structure.
%
%   Syntax
%   [Ac,Bc,Cc,Dc]=ssf2ssc(SSF)
%   [Ac,Bc,Cc,Dc]=ssf2ssc(SSF,ss)
%
%   Description
%
%   ssf = [{A1} {B1} {Ct1} {D1}
%            ...
%          {An} {Bn} {Ctn} {Dn}]
%
%   ss =  additional gain factor
%
%   References: [DSV1, chap. 5.2.1, 5.2.2 and 7.1.3.&4.]
%
%   See also DSV-Lib: sos2ss1, sos2ssc
%      

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(1,2,nargin))
%
nb=size(SSF,1);
if nargin<2, sf=1.;else sf=prod(ss); end   % Scaling parameter
Ac=cell(nb,nb); Bc=cell(nb,1); Cc=cell(1,nb); 
Dd=[1 1]; 
for ir=1:nb
  [A,B,Ct,D] = ssf_getblk(SSF,ir);
  n=size(A,1);
  Ac(ir,ir)={A};
  Bc(ir,1)={B*prod(Dd)};
  Cc(1,ir)={Ct};
  for i=1:ir-1
      Ac(ir,i)={B*Cc{1,i}*prod(Dd(1:ir-i))};
      Ac(i,ir)={zeros(size(Ac{i,ir-1},1),n)};
  end
  Dd=[1 D Dd(2:end)];
end
Dd=fliplr(Dd);
for ic=1:nb,
  Cc(1,ic)={prod(Dd(2+ic:end))*Cc{1,ic}};
end
Ac=cell2mat(Ac);
Bc=sf*cell2mat(Bc);
Cc=cell2mat(Cc);
Dc=sf*prod(Dd);
%% [EOF] - ssf2ssc
