function sop=ssp2par(varargin)
%SSP2PAR Transformation of parallel struct. in state var. form to SOP-form
%   For the parallel form  the 2. order blocks are determined 
%   from the state variable description. The results are stored in parallel
%   form of  2. kind.
%
%   Syntax
%   sop=ssp2par(A,B,C,D)
%   sop=ssp2par(SSP)    
%    
%  References: [DSV1, chap. 5.2.2 and 7.1.2.]
%
%   See also DSV-Lib: par2ssp, par2ssf, par2par
%            Matlab:  ss2sos

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(1,4,nargin))
if nargin <3,
    A=varargin(1); B=varargin(2); C=varargin(3); D=varargin(4);
else
    A=varargin{1}; B=varargin{2}; C=varargin{3}; D=varargin{4};
end
    n=size(A,1);  %system order
nb= ceil(size(A,1)/2);    
sop=zeros(nb+1,6);
i=0;
ii=0;
while i<n,
    i=i+1;
    idx1=find(A(i,:)); idx2=find(A(:,i));
    r= max(length(idx1),length(idx2));
    if r>2, error('SSP2PAR:not a permissible state matrix'); end
    ii=ii+1;
    A1=A(i:i+r-1,i:i+r-1); B1=B(i:i+r-1,1); C1=C(1,i:i+r-1);
    i=i+r-1;
    sop(ii,:)=ss2sos(A1,B1,C1,0);
end
sop(ii+1,1)=D;
sop=par2par(sop);
%% [EOF] - ssp2par
