function sop=tf2par(b,a)
%TF2PAR: Transformation of transfer function to parallel form of 2. kind
%   For the parallel form of 2. kind the direct throughput is distributed over
%   all parallel sections, see [DSV1, Chapt. 5.2.2]
%
% sop = tf2par(b,a) builds the SOP-matrix  for parallel form of 2. kind. 
%   The system is defined by the transfer function (B,A).
%
%   References: [DSV1, chap. 5.2 and 7.1.3.2]
%
%   See also DSV-Lib: par2par, zp2par
%            Matlab:  tf2zp

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(2,2,nargin))
Lb=length(b); La=length(a);
if Lb>La, 
    error('TF2PAR:Order of numerator polynom exceeds denumerator polynom')
end
[z,p,k] = tf2zp(b,a);
% Calulation of parallel form in extended accuracy 
sop = zp2par(z,p,k);

%% [EOF] - tf2par  
