function [sos,ss]=wdf2sos(wdf,g)
%WDF2SOS Transformation of WDF-matrix to SOS-matrix
%   Wave Digital Filter nach Meerktter
%
%   Syntax
%   [sos,ss]=wdf2sos(wdf)
%   [sos,ss]=wdf2sos(wdf,g)
%
%   Description
% [sos,ss] = wdf2sos(wdf) transfers the scaled or unscaled WDF-Matrix into
%   the normalized SOS-Matrix and the gain factor factor ss. The scaling 
%   factor for the wdf-forms set to g=1.
%
% [sos,ss] = wdf2sos(wdf,g)transfers the WDF-Matrix with regard to the
%   vector of scaling factors g into the normalized SOS-Matrix and the gain ss.

%   References: [DSV1, chap. 6.5.3.5 and 7.1.3.2]
%
%   See also DSV-Lib: sos2wdf


%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(1,2, nargin, 'struct'))
if nargin<2, s=1.; else s=prod(g); end
nb=size(wdf,1);
sos=zeros(nb,6);
for i=1:nb
    bet0=wdf(i,1); bet1=wdf(i,2); bet2=wdf(i,3);
    ga1 =wdf(i,5); ga2=wdf(i,6);
    sos(i,1:3)=[bet0,-(bet1+bet2),bet0+bet1-bet2];
    sos(i,4:6)=[1,-(ga1+ga2),1+ga1-ga2];
end
ss=s;
%% [EOF] - wdf2sos
