function [x,y] = zust(A,B,C,D,v,x0)
%ZUST Calculation of the state- and output-vectors for l,r input/output gates
%
%   Syntax
%   [x,y] = zust(A,B,C,D,v,x0)
%
%   Description
% [x,y]=zust(A,B,C,D,v) calculates the sequence of state vectors and 
%   the sequence of output vectors for a system defined by 
%   the matrices [A,B,C,D]. The sequence of input vectors v and the 
%   initial states x0. For a sytem of order n, l inputs, r outputs and a
%   sequence of length K
%   we use A:n*n, B: n*l, C: r*n, D: r*l 
%   and the sequences (matrices) arev:l*K, x:n*(K+1), y: r*K values.
%
%   References: [DSV1, chap. 5.1 and 5.3.1]
%

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)                                      
%   Authors: Hans W. Schuessler
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------                                                                                                                                                                                                                                                                                                                                                                                                                          
error(nargchk(5,6, nargin, 'struct'))
%
if nargin < 6, n=size(A,1); x0=zeros(n,1); end
K = size(v,2);
x = x0(:);
for k = 1:K;
    x(:,k+1) = A*x(:,k) + B*v(:,k);
    y(:,k)   = C*x(:,k) + D*v(:,k);
end
%% [EOF] - zust

