function z=circlemean(varargin)
%CIRCLEMEAN Mean of complex number calculated separately by radius and angle
% 
%   For z=circlemean(z1,z2,...zn) the means of the absolut values 
%   and the angles of the summands z1,...zn are calculated separately.
%   A new complex number is build by that means.
%   The input values can be assembled as a row vector zz=[z1,...,zn].
%   In particular circlemean is used to build the mean value for 
%   complex numbers positioned close together, like the allocation of 
%   multiple roots in a claster.
%
%   See also: mean

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
%   DSV1-Bibliothek to H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Hans W. Schuessler and Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(2,inf, nargin, 'struct'))
%
zz=[varargin{:}];
zabs=mean(abs(zz));
zang=mean(unwrap(angle(zz)));
z=zabs*exp(j*zang);
%% [EOF] - circlemean
