function [num1,den1,div] = euclidred(num,den)
%EUCLIDRED: Fraction reduction by Euclids Procedure
%
%   [b1,c1]=euclidred(b,c) calculates the numerator and denominator of
%   the reduced fraction. 
%   With [b1,c1,div]=euclidred(b,c) we get optional the common divisor div
%
%   See also: tf2catf 
%   MATLAB: deconv

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Hans. W. Schuessler
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(2,2, nargin, 'struct'))
%
tol=1e-6;
n = length(den); cnt = 0;
p = den; q = num; den0 = q; i = 1;
while (cnt==0 && i<=n)
  m = find(abs(q)>tol,1,'first');   % reduce leading zeros.
  [dummy,r] = deconv(p,q(m:length(q)));
  if (max(abs(r))<tol),
    cnt = 1;
  else
    p = q; den0 = r; q = r; i = i+1;
  end
end
if (cnt==1),
  m = find(abs(den0) > tol,1,'first');
  den0 = den0(m:length(den0));
  num1 = deconv(num,den0);
  den1 = deconv(den,den0);
else
  error ('EUCLIDRED: no common denominator found')
end
if nargout>2, div=den0; end
%% [EOF] - euclidred     
