function [zm,fac]=unitmirror(z,mode)
%UNITMIRROR Mirror complex variable at the unit circle
%
% Example:
%   z  = 0.9* exp(30/189*pi);
%   zm = unitmirror(z);
%   abs(zm) 
%           = 1.1111
%
%   See also
%   SPTool: polystab

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.1
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(1,2, nargin, 'struct'))
%
if nargin<2, mode='all'; 
else
    if ~any(strcmp(mode,{'all','outside'})), error('UNITMIRROR: Parameter ?'); end
end
if strcmp(mode,'outside'),
    zm=z;
    z1=z(abs(z)>1);
    %zm(abs(z)>1)=1./abs(z1).*exp(j*angle(z1));  Revision 8/11/2008
    zm(abs(z)>1)=conj(1./z1);
    fac=prod(1./abs(z1));
else
   % zm=1./abs(z).*exp(j*angle(z)); Revision 8/11/2008
    zm=conj(1./z);
    fac=prod(1./abs(z));
end
%% [EOF] - unitmirror
