function w = energy(b,c);
%ENERGY Energy of a sequence according to Astroems procedure
%
%   Syntax
%   w = energy(b,c)
%
%   Description
% w = energy(b,c)determins the energy w contained in the sequence v(k) 
%   under the condition that the Z transform V(z) is a rational function.
%   b:   Coefficients of the numerator of order m
%   c:   Coefficients of the denominator of order n;
%   Condition:  n>=m;
%
%   References: [DSV1, chap. 2.5.5.3]
%
%   See also DSV-Lib: energyss

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Hans W. Schuessler
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(2,2, nargin, 'struct'))
%
m = length(b)-1; n = length(c)-1;
b = [zeros(1,n-m) b]; w = 0; K = c(1);
for i = n+1:-1:2;
   r = c(i)/c(1);
   ro = b(i)/c(1);
   w = w + b(i)*ro;
   b = b(1:i-1) - ro*c(i:-1:2);
   c = c(1:i-1) - r*c(i:-1:2);
end;
ro = b/c; w = (w + b*ro)/K;
%% [EOF] - energy
