function [L,r]=isposdef(S)
%ISPOSDEF Check if matrix is positive definite
%
%   Syntax
%   [L,r]=isposdef(S)
%
%   The logical variable is returned tru, if the matrix S is positiv
%   definite
%
%   References: [DSV1, chap. 5.6.3]
%
%   See also DSV-Lib: syspassiv, sysstable, syscontrol, sysobserve

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(1,1, nargin, 'struct'))
n=max(size(S));
d=eig(S);
r=rank(S);
L=all(d>eps);
if ~L,
  dd=find(abs(d)<eps); nz=length(dd);
  if nz==0, return; 
  else
  L=(n-r==nz);
  end
end
%% [EOF] - isposdef
