function [ctr,S0,vctr]=syscontrol(A,B)
%SYSCONTROL Check for controllability of a system 
%   The system is defined by the state matrices (A,B,C,D)
%
%   Syntax
%   ctr=syscontrol(A,B)
%   [ctr,S0,vctr]=syscontrol(A,B)
%
%   Description
%   The test returns the parameter ctr
%   ctr =0: System is not controllable
%   ctr =1: System is controllable
%   ctr =2: System having more than one entrance is total controllable 
%   Optionally the test returns the control matrix S0 and a vector vctr
%   containing the test results for the individual entrances.
% 
%   References: [DSV1, chap. 5.2.4]
%
%   See also DSV-Lib: sysobserve
%            Matlab:  eig, rank

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(2,2, nargin, 'struct'))
%
nc=length(A);  S=B;
La=size(B,2);
for n=1:1:nc-1,
    S=[S,A^n*B];
end
S0=S;  rk = rank(S0); unco=nc-rk; 
ctr=isequal(unco,0);
% Verification of complete controllability
vctr=[];
if ctr && La>1,
  for la=1:La,
    bla=B(:,la);  S=bla;
    for n=1:1:nc-1,
      S=[S,A^n*bla];
    end 
    vctr(la)=isequal(nc-rank(S),0);
  end
  if ctr && all(vctr),ctr=2; end
end
%% [EOF] - syscontrol
