function [ctr,B0t,vctr]=sysobserve(A,C)
%SYOBSERVE Verification of the observability of a system
%
%   Syntax
%   ctr=sysobserve(A,C)
%   [ctr,B0t,vctr]=sysobserve(A,C)
%
%   Description
%   The test returns the parameter ctr
%   ctr =0: System is not observable
%   ctr =1: System is observable
%   ctr =2: System having more than one exit is total observable 
%
%   Optionally the test returns the control matrix B0t and a vector vctr
%   containing the test results for the individual exits.
% 
%   References: [DSV1, chap. 5.2.4]
%
%   See also DSV-Lib: syscontrol
%            Matlab:  eig, rank

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(2,2, nargin, 'struct'))
%
nc=length(A); La=size(C,1);
Ct=C'; Bt=Ct;  At=A'; 
for n=1:1:nc-1,
    Bt=[Bt,At^n*Ct];
end
B0t=Bt;  rk = rank(B0t); unco=nc-rk; 
ctr=isequal(unco,0);
% Verification of complete observability
vctr=[];
if ctr && La>1,
  for la=1:La,
    cla=C(la,:)';  B0=cla;
    for n=1:1:nc-1,
      B0=[B0,At^n*cla];
    end 
    vctr(la)=isequal(nc-rank(B0),0);
  end
  if ctr && all(vctr),ctr=2; end
end
%% [EOF] - syscontrol
