function [stab,r,N] = sysstable(c)
%SYSSTABLE: Calculation of the Schur-Cohn stability test
%
%   Syntax
%   stab = sysstable(c)
%   [stab,r,N] = sysstable(c)
%
%   Description
% stab=sysstable(c) returns logical parameter if the denominator 
%   coefficients c  belong to a stable system or not
% [stab,r,N]=sysstable(c) makes optionally available 
%   the vector r and the Matrix N of the coefficients of 
%   internal polynomials N_lamda, see references.
%
%   References: [DSV1, chap. 5.5.1]
%
%   See also DSV-Lib: isposdef, syspassiv

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Hans W. Schuessler
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(1,1, nargin, 'struct'))
%
c = c(:)'; n1 = length(c); rr = []; NN = c;
for i = n1:-1:2;
  ri = c(i);
  rr = [rr ri];
  c  = (c(1:i-1) - ri*c(i:-1:2))/(1-ri^2);
  NN = [NN;[zeros(1,n1+1-i) c]];
end
stab=~any(abs(rr)>1);
% Optional Output
if nargout>1, r=rr; end
if nargout>2, N=NN; end
%% [] - sysstable
