function V = cdft(v,om1,om2,N)
%CDFT Chirp-Z-Transformation
%
%   Syntax
%   V = cdft(v,om1,om2,N)
%
%   Description
%   N values of the Chirp Z-transformation are returned in the frequency 
%   range om1 to om2 for the sequence v(k). 
%
%   References: [DSV1, chap. 2.5.5.4]
%
%   See also Matlab: czt, fft

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Hans. W. Schuessler
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(4,4, nargin, 'struct'))
a = exp(j*om1);  b=exp(j*om2);
v =v(:); M=length(v);
M0=2^ceil(log2(M+N-1));
k1= (-(M-1):(N-1))'; k = (0:M-1)';  mu=(0:N-1)';
x= b.^(k1.^2/2);
y=v.*(a.^(-k)).*(b.^(-k.^2/2));
bmu=b.^(-mu.^2/2);
u=ifft(fft(x,M0).*fft(y,M0));
V=bmu.*u(M:(M+N-1));
%% [EOF] - cdft
