 function V = goertz0(v,om)
%GOERTZ0 Calculation of a spectral line according "Goertzel"
%
%   Syntax
%   V = goertz0(v,om)
%
%   Description
%   The "Goertzel'" algorithm is calculated at the frequency values stored in
%   vector om for the input sequence v8k9.
%
%   References: [DSV1, chap. 5.6.4]
%
%   See also Matlab: goertzel, fft

%%  ---------------------------------------------------------------
%   DSV1-Bibliothek zu H.W. Schuessler: Digitale Signalverarbeitung 1,
%                      Springer (2008)
%   Authors: Hans. W. Schuessler and Guenter F. Dehner
%   Version: 1.0
%   Copyright 2007 by authors - not released for commercial use
%%  ---------------------------------------------------------------
error(nargchk(2,2, nargin, 'struct'))
%
 M = length(v);
 b = [0 1 0]; c= [1 -2*cos(om) 1];
 [y,x] = filter(b,c,v);
 V = [exp(j*om) 1]*x;
%% [] - goerz0

